@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 # This file is part of PyTango (http://pytango.rtfd.io)
 #
@@ -17,16 +16,17 @@ usage: client clock_dev_name
 """
 
 import sys
-import PyTango
+import tango
 
 if len(sys.argv) != 2:
     print("must provide one and only one clock device name")
     sys.exit(1)
 
-clock = PyTango.DeviceProxy(sys.argv[1])
+clock = tango.DeviceProxy(sys.argv[1])
 t = clock.time
 gmt = clock.gmtime
 noon = clock.noon
+display = clock.display
 print(t)
 print(gmt)
 print(noon, noon.name, noon.value)
@@ -34,3 +34,13 @@ if noon == noon.AM:
     print('Good morning!')
 print(clock.ctime(t))
 print(clock.mktime(gmt))
+print(display, display.name, display.value)
+clock.display = display.ANALOG
+clock.display = 'DIGITAL'  # you can use a valid string to set the value
+print(clock.display, clock.display.name, clock.display.value)
+display_type = type(display)  # or even create your own IntEnum type
+analog = display_type(0)
+clock.display = analog
+print(clock.display, clock.display.name, clock.display.value)
+clock.display = clock.display.DIGITAL
+print(clock.display, clock.display.name, clock.display.value)
