@@ -130,17 +130,17 @@ namespace PyAttribute
             throw_wrong_python_data_type(att.get_name(), "set_value()");
         }
 
-	PyObject* data_ptr = data.ptr();
-	Py_buffer view;
-	
-	if (PyObject_GetBuffer(data_ptr, &view, PyBUF_FULL_RO) < 0)
-	{
-	    throw_wrong_python_data_type(att.get_name(), "set_value()");
-	}
+        PyObject* data_ptr = data.ptr();
+        Py_buffer view;
 
-	Tango::DevString val_str_real = val_str;
-        att.set_value(&val_str_real, (Tango::DevUChar*)view.buf, (long)view.len);	
-	PyBuffer_Release(&view);
+        if (PyObject_GetBuffer(data_ptr, &view, PyBUF_FULL_RO) < 0)
+        {
+            throw_wrong_python_data_type(att.get_name(), "set_value()");
+        }
+
+        Tango::DevString val_str_real = val_str;
+            att.set_value(&val_str_real, (Tango::DevUChar*)view.buf, (long)view.len);
+        PyBuffer_Release(&view);
     }
 
     /**
@@ -765,8 +765,10 @@ void export_attribute()
         .def("is_polled", &PyAttribute::is_polled)
         .def("check_alarm", &Tango::Attribute::check_alarm)
         .def("get_writable", &Tango::Attribute::get_writable)
-        .def("get_name", &Tango::Attribute::get_name,
-            return_value_policy<copy_non_const_reference>())
+        .def("get_name",
+            (std::string const& (Tango::Attribute::*) () const)
+            &Tango::Attribute::get_name,
+            return_value_policy<copy_const_reference>())
         .def("get_data_type", &Tango::Attribute::get_data_type)
         .def("get_data_format", &Tango::Attribute::get_data_format)
         .def("get_assoc_name", &Tango::Attribute::get_assoc_name, 
