@@ -20,11 +20,44 @@
 #include "to_py.h"
 #include "server/pipe.h"
 
+#include <boost/utility/enable_if.hpp>
 
 extern const char *param_must_be_seq;
 
 using namespace boost::python;
 
+// cppTango since 9.4 version provides a way to stream in code location
+// information wrapped in a LoggerStream::SourceLocation struct. Below
+// template is used as a fallback if this struct is not defined. If it
+// is and has non-zero size, the specialization defined later is used.
+template<typename Stream, typename = void>
+struct LogToStreamImpl
+{
+    static void log(Stream& stream,
+        const std::string& /*file*/, int /*line*/, const std::string& msg)
+    {
+        stream << log4tango::_begin_log << msg;
+    }
+};
+
+template<typename Stream>
+struct LogToStreamImpl<Stream,
+    typename boost::enable_if_c<(sizeof(typename Stream::SourceLocation) > 0)>::type>
+{
+    static void log(Stream& stream,
+        const std::string& file, int line, const std::string& msg)
+    {
+        typename Stream::SourceLocation location = {file.c_str(), line};
+        stream << log4tango::_begin_log << location << msg;
+    }
+};
+
+static void log_to_stream(log4tango::LoggerStream& stream,
+    const std::string& file, int line, const std::string& msg)
+{
+    LogToStreamImpl<log4tango::LoggerStream>::log(stream, file, line, msg);
+}
+
 #define __AUX_DECL_CALL_DEVICE_METHOD \
     AutoPythonGIL __py_lock;
 
@@ -190,7 +223,7 @@ namespace PyDeviceImpl
     {
         return to_list<std::vector<std::string> >::convert(self.get_polled_attr());
     }
-    
+
     inline PyObject* get_non_auto_polled_cmd(Tango::DeviceImpl &self)
     {
         return to_list<std::vector<std::string> >::convert(self.get_non_auto_polled_cmd());
@@ -200,7 +233,7 @@ namespace PyDeviceImpl
     {
         return to_list<std::vector<std::string> >::convert(self.get_non_auto_polled_attr());
     }
-    
+
     /* **********************************
      * change event USING set_value
      * **********************************/
@@ -513,7 +546,7 @@ namespace PyDeviceImpl
     	Tango::DevicePipeBlob dpb;
     	bool reuse = false;
     	PyDevicePipe::set_value(dpb, pipe_data);
-    	self.push_pipe_event(__pipe_name, &dpb, reuse);        
+    	self.push_pipe_event(__pipe_name, &dpb, reuse);
     }
 
     void check_attribute_method_defined(PyObject *self,
@@ -557,11 +590,11 @@ namespace PyDeviceImpl
                        boost::python::object is_allowed_meth_name)
     {
         Tango::Attr &new_attr = const_cast<Tango::Attr &>(c_new_attr);
-        
+
         std::string
             attr_name = new_attr.get_name(),
             read_name_met, write_name_met, is_allowed_method;
-            
+
         if (read_meth_name.ptr() == Py_None)
         {
             read_name_met = "read_" + attr_name;
@@ -588,7 +621,7 @@ namespace PyDeviceImpl
         {
             is_allowed_method = boost::python::extract<const char *>(is_allowed_meth_name);
         }
-        
+
         Tango::AttrWriteType attr_write = new_attr.get_writable();
 
         //
@@ -644,11 +677,11 @@ namespace PyDeviceImpl
         py_attr_ptr->set_read_name(read_name_met);
         py_attr_ptr->set_write_name(write_name_met);
         py_attr_ptr->set_allowed_name(is_allowed_method);
-        
+
         if (new_attr.get_memorized())
             attr_ptr->set_memorized();
         attr_ptr->set_memorized_init(new_attr.get_memorized_init());
-        
+
         attr_ptr->set_disp_level(new_attr.get_disp_level());
         attr_ptr->set_polling_period(new_attr.get_polling_period());
         attr_ptr->set_change_event(new_attr.is_change_event(),
@@ -656,7 +689,7 @@ namespace PyDeviceImpl
         attr_ptr->set_archive_event(new_attr.is_archive_event(),
                                     new_attr.is_check_archive_criteria());
         attr_ptr->set_data_ready_event(new_attr.is_data_ready_event());
-        
+
         //
         // Install attribute in Tango.
         //
@@ -671,21 +704,30 @@ namespace PyDeviceImpl
     }
 
     void add_command(Tango::DeviceImpl &self, boost::python::object cmd_name, boost::python::object cmd_data,
-    		boost::python::object disp_level, bool device_level = false)
+                     boost::python::object is_allowed_name, boost::python::object disp_level, bool device_level = false)
     {
         std::string name = boost::python::extract<std::string>(cmd_name);
 
         std::string in_desc = boost::python::extract<std::string>(cmd_data[0][1]);
         std::string out_desc = boost::python::extract<std::string>(cmd_data[1][1]);
 
+        std::string is_allowed = boost::python::extract<std::string>(is_allowed_name);
+
         Tango::CmdArgType argtype_in = boost::python::extract<Tango::CmdArgType>(cmd_data[0][0]);
         Tango::CmdArgType argtype_out = boost::python::extract<Tango::CmdArgType>(cmd_data[1][0]);
         Tango::DispLevel display_level = boost::python::extract<Tango::DispLevel>(disp_level);
 
         PyCmd *cmd_ptr = new PyCmd(name, argtype_in, argtype_out, in_desc, out_desc, display_level);
+
+        if (!is_allowed.empty())
+        {
+            cmd_ptr->set_allowed(is_allowed);
+        }
+
         //
         // Install the command in Tango.
         //
+
         self.add_command(cmd_ptr, device_level);
     }
 
@@ -696,67 +738,67 @@ namespace PyDeviceImpl
         self.remove_command(name, free_it, clean_db);
     }
 
-    inline void debug(Tango::DeviceImpl &self, const std::string &msg)
+    inline void debug(Tango::DeviceImpl &self, const std::string& file, int line, const std::string &msg)
     {
         if (self.get_logger()->is_debug_enabled()) {
-	    self.get_logger()->debug_stream() 
-	      << log4tango::LogInitiator::_begin_log << msg;
-	}
+            log4tango::LoggerStream stream = self.get_logger()->debug_stream();
+            log_to_stream(stream, file, line, msg);
+        }
     }
 
-    inline void info(Tango::DeviceImpl &self, const std::string &msg)
+    inline void info(Tango::DeviceImpl &self, const std::string& file, int line, const std::string &msg)
     {
         if (self.get_logger()->is_info_enabled()) {
-	    self.get_logger()->info_stream() 
-	      << log4tango::LogInitiator::_begin_log << msg;
-	}
+            log4tango::LoggerStream stream = self.get_logger()->info_stream();
+            log_to_stream(stream, file, line, msg);
+        }
     }
 
-    inline void warn(Tango::DeviceImpl &self, const std::string &msg)
+    inline void warn(Tango::DeviceImpl &self, const std::string& file, int line, const std::string &msg)
     {
         if (self.get_logger()->is_warn_enabled()) {
-	    self.get_logger()->warn_stream() 
-	      << log4tango::LogInitiator::_begin_log << msg;
-	}
+            log4tango::LoggerStream stream = self.get_logger()->warn_stream();
+            log_to_stream(stream, file, line, msg);
+        }
     }
 
-    inline void error(Tango::DeviceImpl &self, const std::string &msg)
+    inline void error(Tango::DeviceImpl &self, const std::string& file, int line, const std::string &msg)
     {
         if (self.get_logger()->is_error_enabled()) {
-	    self.get_logger()->error_stream() 
-	      << log4tango::LogInitiator::_begin_log << msg;
-	}
+            log4tango::LoggerStream stream = self.get_logger()->error_stream();
+            log_to_stream(stream, file, line, msg);
+        }
     }
 
-    inline void fatal(Tango::DeviceImpl &self, const std::string &msg)
+    inline void fatal(Tango::DeviceImpl &self, const std::string& file, int line, const std::string &msg)
     {
         if (self.get_logger()->is_fatal_enabled()) {
-	    self.get_logger()->fatal_stream() 
-	      << log4tango::LogInitiator::_begin_log << msg;
-	}
+            log4tango::LoggerStream stream = self.get_logger()->fatal_stream();
+            log_to_stream(stream, file, line, msg);
+        }
     }
-    
+
     PyObject* get_attribute_config(Tango::DeviceImpl &self, object &py_attr_name_seq)
     {
         Tango::DevVarStringArray par;
         convert2array(py_attr_name_seq, par);
-        
-        Tango::AttributeConfigList *attr_conf_list_ptr = 
+
+        Tango::AttributeConfigList *attr_conf_list_ptr =
             self.get_attribute_config(par);
-        
+
         boost::python::list ret = to_py(*attr_conf_list_ptr);
         delete attr_conf_list_ptr;
-        
+
         return boost::python::incref(ret.ptr());
     }
-    
+
     void set_attribute_config(Tango::DeviceImpl &self, object &py_attr_conf_list)
     {
         Tango::AttributeConfigList attr_conf_list;
         from_py_object(py_attr_conf_list, attr_conf_list);
         self.set_attribute_config(attr_conf_list);
     }
-    
+
     bool is_attribute_polled(Tango::DeviceImpl &self, const std::string &att_name)
     {
         DeviceImplWrap *self_w = (DeviceImplWrap*)(&self);
@@ -903,13 +945,13 @@ namespace PyDevice_2Impl
     {
         Tango::DevVarStringArray par;
         convert2array(attr_name_seq, par);
-        
-        Tango::AttributeConfigList_2 *attr_conf_list_ptr = 
+
+        Tango::AttributeConfigList_2 *attr_conf_list_ptr =
             self.get_attribute_config_2(par);
-        
+
         boost::python::list ret = to_py(*attr_conf_list_ptr);
         delete attr_conf_list_ptr;
-        
+
         return boost::python::incref(ret.ptr());
     }
 
@@ -928,7 +970,7 @@ PyDeviceImplBase::~PyDeviceImplBase()
 
 void PyDeviceImplBase::py_delete_dev()
 {}
- 
+
 Device_3ImplWrap::Device_3ImplWrap(PyObject *self, CppDeviceClass *cl,
                                    std::string &st)
     :Tango::Device_3Impl(cl,st),
@@ -1085,16 +1127,16 @@ namespace PyDevice_3Impl
     {
         Tango::DevVarStringArray par;
         convert2array(attr_name_seq, par);
-        
-        Tango::AttributeConfigList_3 *attr_conf_list_ptr = 
+
+        Tango::AttributeConfigList_3 *attr_conf_list_ptr =
             self.get_attribute_config_3(par);
-        
+
         boost::python::list ret = to_py(*attr_conf_list_ptr);
         delete attr_conf_list_ptr;
-        
+
         return boost::python::incref(ret.ptr());
     }
-    
+
     void set_attribute_config_3(Tango::Device_3Impl &self, object &py_attr_conf_list)
     {
         Tango::AttributeConfigList_3 attr_conf_list;
@@ -1254,7 +1296,7 @@ void Device_4ImplWrap::signal_handler(long signo)
     {
         long nb_err = df.errors.length();
         df.errors.length(nb_err + 1);
-        
+
         df.errors[nb_err].reason = CORBA::string_dup(
             "PyDs_UnmanagedSignalHandlerException");
         df.errors[nb_err].desc = CORBA::string_dup(
@@ -1422,7 +1464,7 @@ void Device_5ImplWrap::signal_handler(long signo)
     {
         long nb_err = df.errors.length();
         df.errors.length(nb_err + 1);
-        
+
         df.errors[nb_err].reason = CORBA::string_dup(
             "PyDs_UnmanagedSignalHandlerException");
         df.errors[nb_err].desc = CORBA::string_dup(
@@ -1456,22 +1498,13 @@ BOOST_PYTHON_MEMBER_FUNCTION_OVERLOADS(set_archive_event_overload,
                                        Tango::DeviceImpl::set_archive_event, 2, 3)
 BOOST_PYTHON_FUNCTION_OVERLOADS(remove_attribute_overload,
                                 PyDeviceImpl::remove_attribute, 2, 3)
-                                       
+
 void export_device_impl()
 {
- 
-    // The following function declarations are necessary to be able to cast
-    // the function parameters from string& to const string&, otherwise python
-    // will not recognize the method calls
-    long (Tango::DeviceImpl::*get_cmd_poll_ring_depth_)(std::string &) =
-        &Tango::DeviceImpl::get_cmd_poll_ring_depth;
-    long (Tango::DeviceImpl::*get_attr_poll_ring_depth_)(std::string &) =
-        &Tango::DeviceImpl::get_attr_poll_ring_depth;
 
-    
     void (Tango::DeviceImpl::*stop_polling1)() = &Tango::DeviceImpl::stop_polling;
     void (Tango::DeviceImpl::*stop_polling2)(bool) = &Tango::DeviceImpl::stop_polling;
-    
+
     class_<Tango::DeviceImpl, std::auto_ptr<DeviceImplWrap>, boost::noncopyable>("DeviceImpl",
         init<CppDeviceClass *, const char *,
              boost::python::optional<const char *, Tango::DevState, const char *> >())
@@ -1520,7 +1553,7 @@ void export_device_impl()
         .def("poll_command", &PyDeviceImpl::poll_command)
         .def("stop_poll_attribute", &PyDeviceImpl::stop_poll_attribute)
         .def("stop_poll_command", &PyDeviceImpl::stop_poll_command)
-                        
+
         .def("get_exported_flag", &Tango::DeviceImpl::get_exported_flag)
         .def("get_poll_ring_depth", &Tango::DeviceImpl::get_poll_ring_depth)
         .def("get_poll_old_factor", &Tango::DeviceImpl::get_poll_old_factor)
@@ -1537,16 +1570,16 @@ void export_device_impl()
         .def("get_dev_idl_version", &Tango::DeviceImpl::get_dev_idl_version)
         .def("get_cmd_poll_ring_depth",
             (long (Tango::DeviceImpl::*) (const std::string &))
-            get_cmd_poll_ring_depth_)
+            &Tango::DeviceImpl::get_cmd_poll_ring_depth)
         .def("get_attr_poll_ring_depth",
             (long (Tango::DeviceImpl::*) (const std::string &))
-            get_attr_poll_ring_depth_)
+            &Tango::DeviceImpl::get_attr_poll_ring_depth)
         .def("is_device_locked", &Tango::DeviceImpl::is_device_locked)
-        
+
         .def("init_logger", &Tango::DeviceImpl::init_logger)
         .def("start_logging", &Tango::DeviceImpl::start_logging)
         .def("stop_logging", &Tango::DeviceImpl::stop_logging)
-        
+
         //.def("set_exported_flag", &Tango::DeviceImpl::set_exported_flag)
         //.def("set_poll_ring_depth", &Tango::DeviceImpl::set_poll_ring_depth)
 
@@ -1704,17 +1737,17 @@ void export_device_impl()
         .def("__fatal_stream", &PyDeviceImpl::fatal)
 
         .def("get_min_poll_period", &Tango::DeviceImpl::get_min_poll_period)
-        .def("get_cmd_min_poll_period", 
+        .def("get_cmd_min_poll_period",
             &Tango::DeviceImpl::get_cmd_min_poll_period,
             return_internal_reference<>())
-        .def("get_attr_min_poll_period", 
+        .def("get_attr_min_poll_period",
             &Tango::DeviceImpl::get_attr_min_poll_period,
             return_internal_reference<>())
 	.def("is_there_subscriber",
 	     &Tango::DeviceImpl::is_there_subscriber)
     ;
     implicitly_convertible<std::auto_ptr<DeviceImplWrap>, std::auto_ptr<Tango::DeviceImpl> >();
-    
+
     class_<Tango::Device_2Impl, Device_2ImplWrap,
            bases<Tango::DeviceImpl>,
            boost::noncopyable>
