@@ -16,7 +16,6 @@ Documentation for this package can be found online:
 http://pytango.readthedocs.io
 """
 
-from __future__ import print_function
 
 __all__ = (
     'AccessControlType', 'ApiUtil', 'ArchiveEventInfo',
@@ -47,7 +46,7 @@ __all__ = (
     'DeviceDataHistory', 'DeviceDataHistoryList',
     'DeviceImpl', 'DeviceInfo', 'DeviceProxy',
     'DeviceUnlocked', 'Device_2Impl', 'Device_3Impl', 'Device_4Impl', 'Device_5Impl',
-    'DispLevel', 'EncodedAttribute', 'ErrSeverity', 'ErrorIt',
+    'DispLevel', 'EncodedAttribute', 'EnsureOmniThread', 'ErrSeverity', 'ErrorIt',
     'EventData', 'EventProperties', 'EventSystemFailed', 'EventType',
     'Except', 'ExtractAs', 'FMT_UNKNOWN', 'FatalIt', 'GreenMode', 'Group',
     'GroupAttrReply',
@@ -74,66 +73,12 @@ __all__ = (
     'AutoTangoAllowThreads', 'LatestDeviceImpl', 'Interceptors',
     'get_attribute_proxy', 'requires_tango', 'requires_pytango',
     'set_green_mode', 'get_green_mode', 'get_device_proxy',
-    'is_scalar_type', 'is_array_type', 'is_numerical_type',
+    'is_scalar_type', 'is_array_type', 'is_omni_thread', 'is_numerical_type',
     'is_int_type', 'is_float_type', 'is_bool_type', 'is_str_type',
     'obj_2_str', 'str_2_obj', 'seqStr_2_obj')
 
 __docformat__ = "restructuredtext"
 
-
-# Prepare windows import
-
-def __prepare_nt():
-    import os
-    import sys
-    import struct
-
-    if os.name != 'nt':
-        return
-
-    try:
-        from . import _tango  # noqa: F401
-    except ImportError:
-        pass
-    else:
-        return
-
-    PATH = os.environ.get('PATH')
-    if PATH is None:
-        os.environ["PATH"] = PATH = ""
-    tango_root = os.environ.get("TANGO_ROOT")
-    if tango_root is None:
-        tango_root = os.path.join(os.environ["ProgramFiles"], "tango")
-    tango_root = tango_root.lower()
-
-    if sys.hexversion < 0x03030000:
-        vc = "vc9_dll"
-    else:
-        vc = "vc10_dll"
-    is64 = 8 * struct.calcsize("P") == 64
-    if is64:
-        arch = "win64"
-    else:
-        arch = "win32"
-    tango_dll_path = os.path.join(tango_root, arch, "lib", vc)
-    tango_dll_path = tango_dll_path.lower()
-    if os.path.exists(tango_dll_path) and \
-       tango_dll_path not in PATH.lower():
-        os.environ['PATH'] += ";" + tango_dll_path
-    else:
-        # Tango C++ could not be found on the system...
-        # ... use PyTango's private Tango C++ library
-        tango_dll_path = os.path.dirname(os.path.abspath(__file__))
-        tango_dll_path = os.path.join(tango_dll_path, "_tango_dll_")
-        if os.path.exists(tango_dll_path):
-            os.environ['PATH'] += ";" + tango_dll_path
-
-
-__prepare_nt()
-
-
-# Boost imports
-
 from ._tango import (
     AccessControlType, ApiUtil, ArchiveEventInfo,
     AsynCall, AsynReplyNotArrived, AttReqType, Attr, AttrConfEventData,
@@ -156,8 +101,8 @@ from ._tango import (
     DeviceAttribute, DeviceAttributeConfig, DeviceAttributeHistory,
     DeviceData, DeviceDataList, DeviceDataHistory, DeviceDataHistoryList,
     DeviceImpl, DeviceInfo, DeviceProxy, DeviceUnlocked, Device_2Impl,
-    Device_3Impl, Device_4Impl, Device_5Impl, DispLevel, EncodedAttribute, ErrSeverity,
-    EventData, EventSystemFailed, EventType, PipeEventData,
+    Device_3Impl, Device_4Impl, Device_5Impl, DispLevel, EncodedAttribute,
+    EnsureOmniThread, ErrSeverity, EventData, EventSystemFailed, EventType, PipeEventData,
     Except, ExtractAs, GreenMode, FMT_UNKNOWN, GroupAttrReply, GroupAttrReplyList,
     GroupCmdReply, GroupCmdReplyList, GroupReply, GroupReplyList,
     IMAGE, ImageAttr, KeepAliveCmdCode, Level, LockCmdCode, LockerInfo,
@@ -172,7 +117,7 @@ from ._tango import (
     UserDefaultAttrProp, UserDefaultPipeProp, WAttribute, WRITE, WrongData,
     WrongNameSyntax, alarm_flags, asyn_req_type, cb_sub_model, constants,
     raise_asynch_exception, Interceptors,
-    AutoTangoMonitor, AutoTangoAllowThreads)
+    AutoTangoMonitor, AutoTangoAllowThreads, is_omni_thread)
 
 
 # Aliases
@@ -186,7 +131,8 @@ from .release import Release
 
 __author__ = Release.author_lines
 __version_info__ = Release.version_info
-__version__ = Release.version
+__version_short__ = Release.version
+__version__ = Release.version_long
 __version_long__ = Release.version_long
 __version_number__ = Release.version_number
 __version_description__ = Release.version_description
@@ -234,3 +180,4 @@ from .device_proxy import get_device_proxy
 
 from .pytango_init import init as __init
 __init()
+requires_tango("9.4.1", software_name="PyTango")
