@@ -9,9 +9,6 @@
 # See LICENSE.txt for more info.
 # -----------------------------------------------------------------------------
 
-# Future imports
-from __future__ import absolute_import
-
 # Imports
 import functools
 
@@ -24,6 +21,10 @@ try:
     from asyncio import run_coroutine_threadsafe
 except ImportError:
     from .asyncio_tools import run_coroutine_threadsafe
+try:
+    from asyncio import coroutine
+except ImportError:
+    from .asyncio_tools import coroutine
 
 # Tango imports
 from .green import AbstractExecutor
@@ -57,7 +58,7 @@ class AsyncioExecutor(AbstractExecutor):
     default_wait = False
 
     def __init__(self, loop=None, subexecutor=None):
-        super(AsyncioExecutor, self).__init__()
+        super().__init__()
         if loop is None:
             try:
                 loop = asyncio.get_event_loop()
@@ -82,13 +83,13 @@ class AsyncioExecutor(AbstractExecutor):
 
     def submit(self, fn, *args, **kwargs):
         """Submit an operation"""
-        corofn = asyncio.coroutine(lambda: fn(*args, **kwargs))
+        corofn = coroutine(lambda: fn(*args, **kwargs))
         return run_coroutine_threadsafe(corofn(), self.loop)
 
     def execute(self, fn, *args, **kwargs):
         """Execute an operation and return the result."""
         if self.in_executor_context():
-            corofn = asyncio.coroutine(lambda: fn(*args, **kwargs))
+            corofn = coroutine(lambda: fn(*args, **kwargs))
             return corofn()
         future = self.submit(fn, *args, **kwargs)
         return future.result()
