@@ -13,10 +13,8 @@
 This is an internal PyTango module.
 """
 
-from __future__ import with_statement
-from __future__ import print_function
 
-__all__ = ["AttrData"]
+__all__ = ("AttrData",)
 
 __docformat__ = "restructuredtext"
 
@@ -28,7 +26,7 @@ from ._tango import Attr, SpectrumAttr, ImageAttr, FwdAttr
 from .utils import is_non_str_seq, is_pure_str
 
 
-class AttrData(object):
+class AttrData:
     """A helper class that contains the same information one of the items in
     DeviceClass.attr_list but in object form"""
 
@@ -163,7 +161,7 @@ class AttrData(object):
 
         for k, v in extra_info.items():
             k_lower = k.lower()
-            method_name = "set_%s" % k_lower.replace(' ', '_')
+            method_name = f"set_{k_lower.replace(' ', '_')}"
             if hasattr(p, method_name):
                 method = getattr(p, method_name)
                 if method_name == 'set_enum_labels':
@@ -173,9 +171,9 @@ class AttrData(object):
             elif k == 'delta_time':
                 p.set_delta_t(str(v))
             elif k_lower not in ('display level', 'polling period', 'memorized'):
-                msg = "Wrong definition of attribute. " \
-                      "The object extra information '%s' " \
-                      "is not recognized!" % (k,)
+                msg = f"Wrong definition of attribute. " \
+                      f"The object extra information '{k}' " \
+                      f"is not recognized!"
                 Except.throw_exception("PyDs_WrongAttributeDefinition", msg,
                                        "create_user_default_attr_prop()")
         return p
@@ -188,14 +186,12 @@ class AttrData(object):
 
         # check parameter
         if not is_non_str_seq(attr_info):
-            throw_ex("Wrong data type for value for describing attribute %s in "
-                     "class %s\nMust be a sequence with 1 or 2 elements"
-                     % (attr_name, name))
+            throw_ex(f"Wrong data type for value for describing attribute {attr_name} in "
+                     f"class {name}\nMust be a sequence with 1 or 2 elements")
 
         if len(attr_info) < 1 or len(attr_info) > 2:
-            throw_ex("Wrong number of argument for describing attribute %s in "
-                     "class %s\nMust be a sequence with 1 or 2 elements"
-                     % (attr_name, name))
+            throw_ex(f"Wrong number of argument for describing attribute {attr_name} in "
+                     f"class {name}\nMust be a sequence with 1 or 2 elements")
 
         extra_info = {}
         if len(attr_info) == 2:
@@ -210,97 +206,94 @@ class AttrData(object):
         # check parameter
         if not is_non_str_seq(attr_info) or \
            attr_info_len < 3 or attr_info_len > 5:
-            throw_ex("Wrong data type for describing mandatory information for "
-                     "attribute %s in class %s\nMust be a sequence with 3, 4 "
-                     "or 5 elements" % (attr_name, name))
+            throw_ex(f"Wrong data type for describing mandatory information for "
+                     f"attribute {attr_name} in class {name}\nMust be a sequence with 3, 4 "
+                     f"or 5 elements")
 
         # get data type
         try:
             self.attr_type = CmdArgType(attr_info[0])
-        except:
-            throw_ex("Wrong data type in attribute argument for attribute %s "
-                     "in class %s\nAttribute data type (first element in first "
-                     "sequence) must be a tango.CmdArgType"
-                     % (attr_name, name))
+        except Exception:
+            throw_ex(f"Wrong data type in attribute argument for attribute {attr_name} "
+                     f"in class {name}\nAttribute data type (first element in first "
+                     f"sequence) must be a tango.CmdArgType")
 
         # get format
         try:
             self.attr_format = AttrDataFormat(attr_info[1])
-        except:
-            throw_ex("Wrong data format in attribute argument for attribute %s "
-                     "in class %s\nAttribute data format (second element in "
-                     "first sequence) must be a tango.AttrDataFormat"
-                     % (attr_name, name))
+        except Exception:
+            throw_ex(f"Wrong data format in attribute argument for attribute {attr_name} "
+                     f"in class {name}\nAttribute data format (second element in "
+                     f"first sequence) must be a tango.AttrDataFormat")
 
         if self.attr_format == AttrDataFormat.SCALAR:
             if attr_info_len != 3:
-                throw_ex("Wrong data type in attribute argument for attribute "
-                         "%s in class %s\nSequence describing mandatory "
-                         "attribute parameters for scalar attribute must have "
-                         "3 elements" % (attr_name, name))
+                throw_ex(f"Wrong data type in attribute argument for attribute "
+                         f"{attr_name} in class {name}\nSequence describing mandatory "
+                         f"attribute parameters for scalar attribute must have "
+                         f"3 elements")
         elif self.attr_format == AttrDataFormat.SPECTRUM:
             if attr_info_len != 4:
-                throw_ex("Wrong data type in attribute argument for attribute "
-                         "%s in class %s\nSequence describing mandatory "
-                         "attribute parameters for spectrum attribute must "
-                         "have 4 elements" % (attr_name, name))
+                throw_ex(f"Wrong data type in attribute argument for attribute "
+                         f"{attr_name} in class {name}\nSequence describing mandatory "
+                         f"attribute parameters for spectrum attribute must "
+                         f"have 4 elements")
             try:
                 self.dim_x = int(attr_info[3])
-            except:
-                throw_ex("Wrong data type in attribute argument for attribute "
-                         "%s in class %s\n4th element in sequence describing "
-                         "mandatory dim_x attribute parameter for spectrum "
-                         "attribute must be an integer" % (attr_name, name))
+            except Exception:
+                throw_ex(f"Wrong data type in attribute argument for attribute "
+                         f"{attr_name} in class {name}\n4th element in sequence describing "
+                         f"mandatory dim_x attribute parameter for spectrum "
+                         f"attribute must be an integer")
         elif self.attr_format == AttrDataFormat.IMAGE:
             if attr_info_len != 5:
-                throw_ex("Wrong data type in attribute argument for attribute "
-                         "%s in class %s\nSequence describing mandatory "
-                         "attribute parameters for image attribute must have "
-                         "5 elements" % (attr_name, name))
+                throw_ex(f"Wrong data type in attribute argument for attribute "
+                         f"{attr_name} in class {name}\nSequence describing mandatory "
+                         f"attribute parameters for image attribute must have "
+                         f"5 elements")
             try:
                 self.dim_x = int(attr_info[3])
-            except:
-                throw_ex("Wrong data type in attribute argument for attribute "
-                         "%s in class %s\n4th element in sequence describing "
-                         "mandatory dim_x attribute parameter for image "
-                         "attribute must be an integer" % (attr_name, name))
+            except Exception:
+                throw_ex(f"Wrong data type in attribute argument for attribute "
+                         f"{attr_name} in class {name}\n4th element in sequence describing "
+                         f"mandatory dim_x attribute parameter for image "
+                         f"attribute must be an integer")
             try:
                 self.dim_y = int(attr_info[4])
-            except:
-                throw_ex("Wrong data type in attribute argument for attribute "
-                         "%s in class %s\n5th element in sequence desribing "
-                         "mandatory dim_y attribute parameter for image "
-                         "attribute must be an integer" % (attr_name, name))
+            except Exception:
+                throw_ex(f"Wrong data type in attribute argument for attribute "
+                         f"{attr_name} in class {name}\n5th element in sequence desribing "
+                         f"mandatory dim_y attribute parameter for image "
+                         f"attribute must be an integer")
 
         # get write type
         try:
             self.attr_write = AttrWriteType(attr_info[2])
-        except:
-            throw_ex("Wrong data write type in attribute argument for "
-                     "attribute %s in class %s\nAttribute write type (third "
-                     "element in first sequence) must be a "
-                     "tango.AttrWriteType" % (attr_name, name))
+        except Exception:
+            throw_ex(f"Wrong data write type in attribute argument for "
+                     f"attribute {attr_name} in class {name}\nAttribute write type (third "
+                     f"element in first sequence) must be a "
+                     f"tango.AttrWriteType")
         try:
             self.display_level = DispLevel(extra_info.get("display level",
                                                           DispLevel.OPERATOR))
-        except:
-            throw_ex("Wrong display level in attribute information for "
-                     "attribute %s in class %s\nAttribute information for "
-                     "display level is not a tango.DispLevel"
-                     % (attr_name, name))
+        except Exception:
+            throw_ex(f"Wrong display level in attribute information for "
+                     f"attribute {attr_name} in class {name}\nAttribute information for "
+                     f"display level is not a tango.DispLevel")
         try:
             self.polling_period = int(extra_info.get("polling period", -1))
-        except:
-            throw_ex("Wrong polling period in attribute information for "
-                     "attribute %s in class %s\nAttribute information for "
-                     "polling period is not an integer" % (attr_name, name))
+        except Exception:
+            throw_ex(f"Wrong polling period in attribute information for "
+                     f"attribute {attr_name} in class {name}\nAttribute information for "
+                     f"polling period is not an integer")
 
         try:
             memorized = extra_info.get("memorized", "false").lower()
-        except:
-            throw_ex("Wrong memorized value. for attribute %s in class %s."
-                     "Allowed valued are the strings \"true\", \"false\" and "
-                     "\"true_without_hard_applied\" (case incensitive)")
+        except Exception:
+            throw_ex(f"Wrong memorized value for attribute {attr_name} in class {name}."
+                     f"Allowed valued are the strings \"true\", \"false\" and "
+                     f"\"true_without_hard_applied\" (case insensitive)")
         if memorized == "true":
             self.memorized = True
             self.hw_memorized = True
@@ -311,8 +304,8 @@ class AttrData(object):
 
         if self.attr_type == CmdArgType.DevEnum:
             if 'enum_labels' not in extra_info:
-                throw_ex("Missing 'enum_labels' key in attr_list definition "
-                         "for enum attribute %s in class %s" % (attr_name, name))
+                throw_ex(f"Missing 'enum_labels' key in attr_list definition "
+                         f"for enum attribute {attr_name} in class {name}")
             self.enum_labels = extra_info["enum_labels"]
 
         self.attr_class = extra_info.get("klass", self.DftAttrClassMap[self.attr_format])
