@@ -17,10 +17,7 @@ To access these members use directly :mod:`tango` module and NOT
 tango.attribute_proxy.
 """
 
-try:
-    import collections.abc as collections_abc  # python 3.3+
-except ImportError:
-    import collections as collections_abc
+import collections.abc
 
 from ._tango import StdStringVector, DbData, DbDatum, DeviceProxy
 from ._tango import __AttributeProxy as _AttributeProxy
@@ -130,7 +127,7 @@ def __AttributeProxy__get_property(self, propname, value=None):
         new_value.append(propname)
         self._get_property(new_value)
         return DbData_2_dict(new_value)
-    elif isinstance(propname, collections_abc.Sequence):
+    elif isinstance(propname, collections.abc.Sequence):
         if isinstance(propname, DbData):
             self._get_property(propname)
             return DbData_2_dict(propname)
@@ -177,7 +174,8 @@ def __AttributeProxy__put_property(self, value):
         Return     : None
 
         Throws     : ConnectionFailed, CommunicationFailed
-                     DevFailed from device (DB_SQLError)
+                     DevFailed from device (DB_SQLError),
+                     TypeError
     """
     if isinstance(value, DbData):
         pass
@@ -187,7 +185,7 @@ def __AttributeProxy__put_property(self, value):
         value = new_value
     elif is_non_str_seq(value):
         new_value = seq_2_DbData(value)
-    elif isinstance(value, collections_abc.Mapping):
+    elif isinstance(value, collections.abc.Mapping):
         new_value = DbData()
         for k, v in value.items():
             if isinstance(v, DbDatum):
@@ -240,7 +238,8 @@ def __AttributeProxy__delete_property(self, value):
         Return     : None
 
         Throws     : ConnectionFailed, CommunicationFailed
-                    DevFailed from device (DB_SQLError)
+                     DevFailed from device (DB_SQLError),
+                     TypeError
     """
     if isinstance(value, DbData) or isinstance(value, StdStringVector) or \
             is_pure_str(value):
@@ -248,14 +247,14 @@ def __AttributeProxy__delete_property(self, value):
     elif isinstance(value, DbDatum):
         new_value = DbData()
         new_value.append(value)
-    elif isinstance(value, collections_abc.Sequence):
+    elif isinstance(value, collections.abc.Sequence):
         new_value = DbData()
         for e in value:
             if isinstance(e, DbDatum):
                 new_value.append(e)
             else:
                 new_value.append(DbDatum(str(e)))
-    elif isinstance(value, collections_abc.Mapping):
+    elif isinstance(value, collections.abc.Mapping):
         new_value = DbData()
         for k, v in value.items():
             if isinstance(v, DbDatum):
@@ -277,7 +276,7 @@ def __AttributeProxy__delete_property(self, value):
 # One reason to do it this way: get_device_proxy() will always return the
 # same tango.DeviceProxy with this implementation. And then we can trust
 # it's automatic event unsubscription to handle events.
-class AttributeProxy(object):
+class AttributeProxy:
     """
         AttributeProxy is the high level Tango object which provides the
         client with an easy-to-use interface to TANGO attributes.
@@ -325,10 +324,10 @@ class AttributeProxy(object):
         return self.__attr_proxy.name()
 
     def __str__(self):
-        return "AttributeProxy(%s)" % self.name()
+        return f"AttributeProxy({self.name()})"
 
     def __repr__(self):
-        return "AttributeProxy(%s)" % self.name()
+        return f"AttributeProxy({self.name()})"
 
 
 def _method_dev_and_name(dp_fn_name, doc=True):
