@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
 """This class manage the TANGO database."""
 
@@ -16,14 +15,11 @@ except ImportError:
 
 import tango
 from tango import AttrWriteType, GreenMode
-from tango.server import Device, DeviceMeta
+from tango.server import Device
 from tango.server import attribute, command
-from tango.server import class_property
-from tango.server import device_property
 from tango.server import run
 
-from tango.globals import get_class, get_class_by_class, \
-    get_constructed_class_by_class
+from tango.globals import get_class_by_class, get_constructed_class_by_class
 
 
 READ_ONLY = AttrWriteType.READ
@@ -31,10 +27,12 @@ WRITE_ONLY = AttrWriteType.WRITE
 READ_WRITE = AttrWriteType.READ_WRITE
 READ_WITH_WRITE = AttrWriteType.READ_WITH_WRITE
 
-#Argument Options
+# Argument Options
 global options
 global WILDCARD_REPLACEMENT
 WILDCARD_REPLACEMENT = True
+
+
 class DbInter(tango.Interceptors):
 
     def create_thread(self):
@@ -43,12 +41,15 @@ class DbInter(tango.Interceptors):
     def delete_thread(self):
         pass
 
+
 DB_NAME = None
 
+
 def set_db_name(db_name):
     global DB_NAME
     DB_NAME = db_name
 
+
 def get_db_name():
     return DB_NAME
 
@@ -59,6 +60,7 @@ th_exc = tango.Except.throw_exception
 
 from .db_errors import *
 
+
 def check_device_name(dev_name):
     if '*' in dev_name:
         return False, None, None
@@ -69,7 +71,7 @@ def check_device_name(dev_name):
         dev_name = dev_name[5:]
     if dev_name.startswith("//"):
         dev_name = dev_name[2:]
-        if not '/' in dev_name or dev_name.startswith("/"):
+        if '/' not in dev_name or dev_name.startswith("/"):
             return False, None, None
     dfm = dev_name.split("/")
     if len(dfm) != 3:
@@ -79,6 +81,7 @@ def check_device_name(dev_name):
         return False, None, None
     return True, dev_name, dfm
 
+
 def replace_wildcard(text):
     if not WILDCARD_REPLACEMENT:
         return text
@@ -94,6 +97,7 @@ def replace_wildcard(text):
     text = text.replace("*", "%")
     return text
 
+
 class TimeStructure:
     def __init__(self):
         self.average = 0
@@ -104,8 +108,10 @@ class TimeStructure:
         self.calls = 0
         self.index = ''
 
+
 def stats(f):
     fname = f.__name__
+
     @functools.wraps(f)
     def wrapper(self, *args, **kwargs):
         start = time.time()
@@ -116,6 +122,7 @@ def stats(f):
             update_timing_stats(self, start, end, fname)
     return wrapper
 
+
 def update_timing_stats(dev, time_before, time_after, cmd_name):
     tmp_time = dev.timing_maps[cmd_name]
     time_elapsed = (time_after - time_before) * 1000.
@@ -125,7 +132,12 @@ def update_timing_stats(dev, time_before, time_after, cmd_name):
     if time_elapsed < tmp_time.minimum or tmp_time.minimum == 0:
         tmp_time.minimum = time_elapsed
     tmp_time.calls = tmp_time.calls + 1
-    tmp_time.average = tmp_time.total_elapsed/tmp_time.calls
+    tmp_time.average = tmp_time.total_elapsed / tmp_time.calls
+
+
+def get_plugin(name):
+    fullname = f'{db_access.__package__}.{name}'
+    return __import__(fullname, None, None, fullname)
 
 
 class DataBase(Device):
@@ -135,27 +147,26 @@ class DataBase(Device):
 
     # --- attributes ---------------------------------------
 
-    Timing_maximum = attribute(dtype=('float64',),max_dim_x=128, access=READ_ONLY)
+    Timing_maximum = attribute(dtype=('float64',), max_dim_x=128, access=READ_ONLY)
 
-    Timing_average = attribute(dtype=('float64',),max_dim_x=128, access=READ_ONLY)
+    Timing_average = attribute(dtype=('float64',), max_dim_x=128, access=READ_ONLY)
 
-    Timing_index = attribute(dtype=('str',),max_dim_x=128, access=READ_ONLY)
+    Timing_index = attribute(dtype=('str',), max_dim_x=128, access=READ_ONLY)
 
-    Timing_calls = attribute(dtype=('float64',),max_dim_x=128, access=READ_ONLY)
+    Timing_calls = attribute(dtype=('float64',), max_dim_x=128, access=READ_ONLY)
 
-    Timing_info = attribute(dtype=('str',),max_dim_x=128, access=READ_ONLY)
+    Timing_info = attribute(dtype=('str',), max_dim_x=128, access=READ_ONLY)
 
     StoredProcedureRelease = attribute(dtype='str', access=READ_ONLY)
 
-    Timing_minimum = attribute(dtype=('float64',),max_dim_x=128, access=READ_ONLY)
+    Timing_minimum = attribute(dtype=('float64',), max_dim_x=128, access=READ_ONLY)
 
     def init_device(self):
-        self._log = log = logging.getLogger(self.get_name())
+        self._log = logging.getLogger(self.get_name())
         self._log.debug("In init_device()")
         self.attr_StoredProcedureRelease_read = ''
         self.init_timing_stats()
-        m = __import__('%s.%s' % (db_access.__package__,options.db_access),None,None,
-                       '%s.%s' % (db_access.__package__,options.db_access))
+        m = get_plugin(options.db_access)
         self.db = m.get_db(personal_name = options.argv[1])
         try:
             global WILDCARD_REPLACEMENT
@@ -1749,14 +1760,17 @@ def main(argv = None):
         (options,args) = parser.parse_args(argv)
         options.argv = ["DataBaseds"] + args
 
+    # Check plugin availability
+    get_plugin(options.db_access)
+
     port = options.port
     if port is None:
         try:
             _, port = tango.ApiUtil.get_env_var("TANGO_HOST").split(":")
-        except:
+        except Exception:
             port = 10000
 
-    options.argv += ["-ORBendPoint", "giop:tcp::{0}".format(port)]
+    options.argv += ["-ORBendPoint", f"giop:tcp:0.0.0.0:{port}"]
 
     log_fmt = '%(threadName)-14s %(levelname)-8s %(asctime)s %(name)s: %(message)s'
     if options.logging_level == 1:
@@ -1792,12 +1806,10 @@ def __monkey_patch_database_class():
         klass = get_constructed_class_by_class(klass)
 
         if info is None:
-            raise RuntimeError("Device class '%s' is not " \
-                               "registered" % klass_name)
+            raise RuntimeError(f"Device class '{klass_name}' is not registered")
 
         if klass is None:
-            raise RuntimeError("Device class '%s' as not been " \
-                               "constructed" % klass_name)
+            raise RuntimeError(f"Device class '{klass_name}' as not been constructed")
 
         deviceClassClass, deviceImplClass, deviceImplName = info
         deviceImplClass._device_class_instance = klass
@@ -1824,7 +1836,7 @@ def __run(db_name,argv):
     """
     Runs the Database DS as a standalone database. Run it with::
 
-        ./DataBaseds pydb-test -ORBendPoint giop:tcp::11000
+        ./DataBaseds pydb-test -ORBendPoint giop:tcp:0.0.0.0:11000
     """
     tango.Util.set_use_db(False)
     util = tango.Util(argv)
