@@ -13,7 +13,7 @@
 This is an internal PyTango module.
 """
 
-__all__ = ["device_attribute_init"]
+__all__ = ("device_attribute_init",)
 
 __docformat__ = "restructuredtext"
 
@@ -34,15 +34,15 @@ def __DeviceAttribute__init(self, da=None):
         DeviceAttribute.__init_orig(self, da)
         try:
             self.value = copy.deepcopy(da.value)
-        except:
+        except Exception:
             pass
         try:
             self.w_value = copy.deepcopy(da.w_value)
-        except:
+        except Exception:
             pass
         try:
             self.scalar_w_value = da.scalar_w_value
-        except:
+        except Exception:
             pass
         self.type = da.type
         self.is_empty = da.is_empty
