@@ -13,20 +13,23 @@
 This is an internal PyTango module.
 """
 
-from __future__ import print_function
 
 import copy
 import functools
+import inspect
+import os
+
+from inspect import getfullargspec
 
 from ._tango import (
     DeviceImpl, Device_3Impl, Device_4Impl, Device_5Impl,
     DevFailed, Attribute, WAttribute, AttrWriteType,
     MultiAttribute, MultiClassAttribute,
-    Attr, Logger, AttrWriteType, AttrDataFormat,
+    Attr, Logger, AttrDataFormat,
     DispLevel, UserDefaultAttrProp, StdStringVector)
 
 from .utils import document_method as __document_method
-from .utils import copy_doc, get_latest_device_class
+from .utils import copy_doc, get_latest_device_class, set_complex_value, is_pure_str
 from .green import get_executor
 from .attr_data import AttrData
 
@@ -53,9 +56,9 @@ def set_worker(worker):
 def get_worker():
     return _WORKER
 
-# patcher for dynamic attribute
 
-def __run_in_executor(fn):
+# patcher for methods
+def run_in_executor(fn):
     if not hasattr(fn, 'wrapped_with_executor'):
         @functools.wraps(fn)
         def wrapper(*args, **kwargs):
@@ -66,15 +69,32 @@ def __run_in_executor(fn):
     else:
         return fn
 
-class LatestDeviceImpl(get_latest_device_class()):
-    __doc__ = """\
-    Latest implementation of the TANGO device base class (alias for {0}).
+def get_source_location():
+    """Helper function that provides source location for logging functions."""
+    # Search the call stack until we are out of the 'tango' module. We cannot
+    # have a fixed number here beause loggers/streams are used in many places
+    # inside pytango with varying call stack depth.
+    for frame, filename, lineno, _, _, _ in inspect.stack():
+        module = frame.f_globals['__name__']
+        if module != "tango" and not module.startswith("tango."):
+            filename = os.path.basename(filename)
+            return filename, lineno
+    return "(unknown)", 0
+
+
+# Note: the inheritance below doesn't call get_latest_device_class(),
+#       because such dynamic inheritance breaks auto-completion in IDEs.
+#       Instead, we manually provide the correct class here, and verify
+#       that the inheritance is correct via a unit test, in test_server.py.
+class LatestDeviceImpl(Device_5Impl):
+    __doc__ = f"""\
+    Latest implementation of the TANGO device base class (alias for {get_latest_device_class().__name__}).
 
     It inherits from CORBA classes where all the network layer is implemented.
-    """.format(get_latest_device_class().__name__)
+    """
 
 
-class AttributeAlarm(object):
+class AttributeAlarm:
     """This class represents the python interface for the Tango IDL object
     AttributeAlarm."""
 
@@ -88,7 +108,7 @@ class AttributeAlarm(object):
         self.extensions = []
 
 
-class ChangeEventProp(object):
+class ChangeEventProp:
     """This class represents the python interface for the Tango IDL object
     ChangeEventProp."""
 
@@ -98,7 +118,7 @@ class ChangeEventProp(object):
         self.extensions = []
 
 
-class PeriodicEventProp(object):
+class PeriodicEventProp:
     """This class represents the python interface for the Tango IDL object
     PeriodicEventProp."""
 
@@ -107,7 +127,7 @@ class PeriodicEventProp(object):
         self.extensions = []
 
 
-class ArchiveEventProp(object):
+class ArchiveEventProp:
     """This class represents the python interface for the Tango IDL object
     ArchiveEventProp."""
 
@@ -118,7 +138,7 @@ class ArchiveEventProp(object):
         self.extensions = []
 
 
-class EventProperties(object):
+class EventProperties:
     """This class represents the python interface for the Tango IDL object
     EventProperties."""
 
@@ -128,7 +148,7 @@ class EventProperties(object):
         self.arch_event = ArchiveEventProp()
 
 
-class MultiAttrProp(object):
+class MultiAttrProp:
     """This class represents the python interface for the Tango IDL object
     MultiAttrProp."""
 
@@ -175,7 +195,7 @@ def _init_attr_config(attr_cfg):
     attr_cfg.extensions = []
 
 
-class AttributeConfig(object):
+class AttributeConfig:
     """This class represents the python interface for the Tango IDL object
     AttributeConfig."""
 
@@ -185,7 +205,7 @@ class AttributeConfig(object):
         self.max_alarm = ''
 
 
-class AttributeConfig_2(object):
+class AttributeConfig_2:
     """This class represents the python interface for the Tango IDL object
     AttributeConfig_2."""
 
@@ -196,7 +216,7 @@ class AttributeConfig_2(object):
         self.max_alarm = ''
 
 
-class AttributeConfig_3(object):
+class AttributeConfig_3:
     """This class represents the python interface for the Tango IDL object
     AttributeConfig_3."""
 
@@ -208,7 +228,7 @@ class AttributeConfig_3(object):
         self.sys_extensions = []
 
 
-class AttributeConfig_5(object):
+class AttributeConfig_5:
     """This class represents the python interface for the Tango IDL object
     AttributeConfig_5."""
 
@@ -275,7 +295,7 @@ def __Attribute__set_properties(self, attr_cfg, dev=None):
 
 
 def __Attribute__str(self):
-    return '%s(%s)' % (self.__class__.__name__, self.get_name())
+    return f'{self.__class__.__name__}({self.get_name()})'
 
 
 def __init_Attribute():
@@ -319,7 +339,7 @@ def __DeviceImpl__get_device_properties(self, ds_class=None):
         try:
             # Call this method in a try/except in case this is called during the DS shutdown sequence
             ds_class = self.get_device_class()
-        except:
+        except Exception:
             return
     try:
         pu = self.prop_util = ds_class.prop_util
@@ -347,6 +367,10 @@ def __DeviceImpl__add_attribute(self, attr, r_meth=None, w_meth=None, is_allo_me
         to the device class attribute list. Therefore, all devices belonging to the
         same class created after this attribute addition will also have this attribute.
 
+        If you pass a reference to unbound method for read, write or is_allowed method
+        (e.g. DeviceClass.read_function or self.__class__.read_function),
+        during execution the corresponding bound method (self.read_function) will be used.
+
         :param attr: the new attribute to be added to the list.
         :type attr: server.attribute or Attr or AttrData
         :param r_meth: the read method to be called on a read request
@@ -369,7 +393,6 @@ def __DeviceImpl__add_attribute(self, attr, r_meth=None, w_meth=None, is_allo_me
 
         :raises DevFailed:
     """
-
     attr_data = None
     if isinstance(attr, AttrData):
         attr_data = attr
@@ -377,7 +400,8 @@ def __DeviceImpl__add_attribute(self, attr, r_meth=None, w_meth=None, is_allo_me
 
     att_name = attr.get_name()
 
-    r_name = 'read_%s' % att_name
+    # get read method and its name
+    r_name = f'read_{att_name}'
     if r_meth is None:
         if attr_data is not None:
             r_name = attr_data.read_method_name
@@ -388,13 +412,24 @@ def __DeviceImpl__add_attribute(self, attr, r_meth=None, w_meth=None, is_allo_me
     else:
         r_name = r_meth.__name__
 
+    # patch it if attribute is readable
     if attr.get_writable() in (AttrWriteType.READ,
                                AttrWriteType.READ_WRITE,
                                AttrWriteType.READ_WITH_WRITE,
                                ):
-        _ensure_user_method_can_be_called(self, r_name, r_meth)
+        r_meth = __ensure_user_method_is_device_attr(self, r_name, r_meth)
 
-    w_name = 'write_%s' % att_name
+        read_args = getfullargspec(r_meth)
+        has_attr_argument = len(read_args.args) - int(__is_method_bound(r_meth))
+
+        r_meth = functools.partial(__dynamic_attribute_reader,
+                                   r_meth=r_meth,
+                                   has_attr_argument=has_attr_argument)
+        r_name = f"__wrapped_{att_name}_{r_name}__"
+        setattr(self, r_name, r_meth)
+
+    # get write method and its name
+    w_name = f'write_{att_name}'
     if w_meth is None:
         if attr_data is not None:
             w_name = attr_data.write_method_name
@@ -405,13 +440,24 @@ def __DeviceImpl__add_attribute(self, attr, r_meth=None, w_meth=None, is_allo_me
     else:
         w_name = w_meth.__name__
 
+    # patch it if attribute is writable
     if attr.get_writable() in (AttrWriteType.WRITE,
                                AttrWriteType.READ_WRITE,
                                AttrWriteType.READ_WITH_WRITE,
                                ):
-        _ensure_user_method_can_be_called(self, w_name, w_meth)
+        w_meth = __ensure_user_method_is_device_attr(self, w_name, w_meth)
 
-    ia_name = 'is_%s_allowed' % att_name
+        write_args = getfullargspec(w_meth)
+        has_value_argument = len(write_args.args) - int(__is_method_bound(w_meth)) - 1  # we always pass attr
+
+        w_meth = functools.partial(__dynamic_attribute_writer,
+                                   w_meth=w_meth,
+                                   has_value_argument=has_value_argument)
+        w_name = f"__wrapped_{att_name}_{w_name}__"
+        setattr(self, w_name, w_meth)
+
+    # get is allowed method and its name
+    ia_name = f'is_{att_name}_allowed'
     if is_allo_meth is None:
         if attr_data is not None:
             ia_name = attr_data.is_allowed_name
@@ -420,14 +466,50 @@ def __DeviceImpl__add_attribute(self, attr, r_meth=None, w_meth=None, is_allo_me
         elif hasattr(self, ia_name):
             is_allo_meth = getattr(self, ia_name)
     else:
-            ia_name = is_allo_meth.__name__
-    _ensure_user_method_can_be_called(self, ia_name, is_allo_meth)
+        ia_name = is_allo_meth.__name__
+
+    # patch it if exists
+    if is_allo_meth is not None:
+        is_allo_meth = __ensure_user_method_is_device_attr(self, ia_name, is_allo_meth)
+        ia_name = f"__wrapped_{att_name}_{ia_name}__"
+
+        setattr(self, ia_name, run_in_executor(is_allo_meth))
 
     self._add_attribute(attr, r_name, w_name, ia_name)
     return attr
 
 
-def _ensure_user_method_can_be_called(obj, name, user_method):
+def __dynamic_attribute_reader(attr, r_meth, has_attr_argument):
+    worker = get_worker()
+
+    if has_attr_argument:
+        ret = worker.execute(r_meth, attr)
+    else:
+        ret = worker.execute(r_meth)
+
+    if not attr.get_value_flag() and ret is not None:
+        set_complex_value(attr, ret)
+
+    return ret
+
+
+def __dynamic_attribute_writer(attr, w_meth, has_value_argument):
+    worker = get_worker()
+
+    if has_value_argument:
+        return worker.execute(w_meth, attr, attr.get_write_value())
+
+    return worker.execute(w_meth, attr)
+
+
+def __is_method_bound(method):
+    """
+    checks if method belongs to any class,
+    """
+    return hasattr(method, '__self__')
+
+
+def __ensure_user_method_is_device_attr(obj, name, user_method):
     if user_method is not None:
 
         # we have to check that user provided us with the device method,
@@ -437,24 +519,11 @@ def _ensure_user_method_can_be_called(obj, name, user_method):
         if not is_device_method:
             # in case user gave us class method, we are trying to find it in device:
             bound_user_method = getattr(obj, name, None)
-            if bound_user_method is None:
-                raise ValueError(
-                    "User-supplied method for attributes must be "
-                    "available as a bound method on the Device class. "
-                    "When accessing Tango attributes, the PyTango extension "
-                    "code, PyAttr::read, uses the name of the method "
-                    "to get a reference to it from the Device object. "
-                    "{} was not found on {}.".format(name, obj)
-                )
-            user_method = bound_user_method
-
-        # If server run in async mode, all calls must be wrapped with async executor:
-        user_method_cannot_be_run_directly = get_worker().asynchronous
-        if user_method_cannot_be_run_directly:
-            setattr(obj, name, __run_in_executor(user_method))
-
-    # else user hasn't provided a method, which may be OK (e.g., using named lookup, or
-    # unnecessary method like a write for a read-only attribute).
+            if bound_user_method:
+                user_method = bound_user_method
+            else:
+                setattr(obj, name, user_method)
+    return user_method
 
 
 def __DeviceImpl__remove_attribute(self, attr_name):
@@ -487,12 +556,30 @@ def __DeviceImpl__add_command(self, cmd, device_level=True):
         :raises DevFailed:
     """
     config = dict(cmd.__tango_command__[1][2])
-    if config and ("Display level" in config):
-        disp_level = config["Display level"]
+    disp_level = DispLevel.OPERATOR
+
+    cmd_name = cmd.__name__
+    fisallowed = "is_{0}_allowed".format(cmd_name)
+
+    if config:
+        if "Display level" in config:
+            disp_level = config["Display level"]
+
+        if "Is allowed" in config:
+            fisallowed = config["Is allowed"]
+
+    if is_pure_str(fisallowed):
+        fisallowed = getattr(self, fisallowed, None)
+
+    if fisallowed is not None:
+        fisallowed_name = f"__wrapped_{getattr(fisallowed, '__name__', f'is_{cmd_name}_allowed')}__"
+        if len(getfullargspec(fisallowed).args) > 1:
+            fisallowed = functools.partial(fisallowed, self)
+        setattr(self, fisallowed_name, run_in_executor(fisallowed))
     else:
-        disp_level = DispLevel.OPERATOR
-    self._add_command(cmd.__name__, cmd.__tango_command__[1], disp_level,
-                      device_level)
+        fisallowed_name = ''
+
+    self._add_command(cmd_name, cmd.__tango_command__[1], fisallowed_name, disp_level, device_level)
     return cmd
 
 
@@ -527,7 +614,10 @@ def __DeviceImpl__debug_stream(self, msg, *args):
         :param msg: the message to be sent to the debug stream
         :type msg: str
     """
-    self.__debug_stream(msg % args)
+    filename, line = get_source_location()
+    if args:
+        msg = msg % args
+    self.__debug_stream(filename, line, msg)
 
 
 def __DeviceImpl__info_stream(self, msg, *args):
@@ -543,7 +633,10 @@ def __DeviceImpl__info_stream(self, msg, *args):
         :param msg: the message to be sent to the info stream
         :type msg: str
     """
-    self.__info_stream(msg % args)
+    filename, line = get_source_location()
+    if args:
+        msg = msg % args
+    self.__info_stream(filename, line, msg)
 
 
 def __DeviceImpl__warn_stream(self, msg, *args):
@@ -559,7 +652,10 @@ def __DeviceImpl__warn_stream(self, msg, *args):
         :param msg: the message to be sent to the warn stream
         :type msg: str
     """
-    self.__warn_stream(msg % args)
+    filename, line = get_source_location()
+    if args:
+        msg = msg % args
+    self.__warn_stream(filename, line, msg)
 
 
 def __DeviceImpl__error_stream(self, msg, *args):
@@ -575,7 +671,10 @@ def __DeviceImpl__error_stream(self, msg, *args):
         :param msg: the message to be sent to the error stream
         :type msg: str
     """
-    self.__error_stream(msg % args)
+    filename, line = get_source_location()
+    if args:
+        msg = msg % args
+    self.__error_stream(filename, line, msg)
 
 
 def __DeviceImpl__fatal_stream(self, msg, *args):
@@ -591,7 +690,10 @@ def __DeviceImpl__fatal_stream(self, msg, *args):
         :param msg: the message to be sent to the fatal stream
         :type msg: str
     """
-    self.__fatal_stream(msg % args)
+    filename, line = get_source_location()
+    if args:
+        msg = msg % args
+    self.__fatal_stream(filename, line, msg)
 
 
 @property
@@ -630,7 +732,7 @@ def __DeviceImpl__fatal(self):
 
 
 def __DeviceImpl__str(self):
-    return '%s(%s)' % (self.__class__.__name__, self.get_name())
+    return f'{self.__class__.__name__}({self.get_name()})'
 
 
 def __init_DeviceImpl():
@@ -668,7 +770,10 @@ def __Logger__log(self, level, msg, *args):
         :param args: list of optional message arguments
         :type args: Sequence[str]
     """
-    self.__log(level, msg % args)
+    filename, line = get_source_location()
+    if args:
+        msg = msg % args
+    self.__log(filename, line, level, msg)
 
 
 def __Logger__log_unconditionally(self, level, msg, *args):
@@ -685,7 +790,10 @@ def __Logger__log_unconditionally(self, level, msg, *args):
         :param args: list of optional message arguments
         :type args: Sequence[str]
     """
-    self.__log_unconditionally(level, msg % args)
+    filename, line = get_source_location()
+    if args:
+        msg = msg % args
+    self.__log_unconditionally(filename, line, level, msg)
 
 
 def __Logger__debug(self, msg, *args):
@@ -699,7 +807,10 @@ def __Logger__debug(self, msg, *args):
         :param args: list of optional message arguments
         :type args: Sequence[str]
     """
-    self.__debug(msg % args)
+    filename, line = get_source_location()
+    if args:
+        msg = msg % args
+    self.__debug(filename, line, msg)
 
 
 def __Logger__info(self, msg, *args):
@@ -713,7 +824,10 @@ def __Logger__info(self, msg, *args):
         :param args: list of optional message arguments
         :type args: Sequence[str]
     """
-    self.__info(msg % args)
+    filename, line = get_source_location()
+    if args:
+        msg = msg % args
+    self.__info(filename, line, msg)
 
 
 def __Logger__warn(self, msg, *args):
@@ -727,7 +841,10 @@ def __Logger__warn(self, msg, *args):
         :param args: list of optional message arguments
         :type args: Sequence[str]
     """
-    self.__warn(msg % args)
+    filename, line = get_source_location()
+    if args:
+        msg = msg % args
+    self.__warn(filename, line, msg)
 
 
 def __Logger__error(self, msg, *args):
@@ -741,7 +858,10 @@ def __Logger__error(self, msg, *args):
         :param args: list of optional message arguments
         :type args: Sequence[str]
     """
-    self.__error(msg % args)
+    filename, line = get_source_location()
+    if args:
+        msg = msg % args
+    self.__error(filename, line, msg)
 
 
 def __Logger__fatal(self, msg, *args):
@@ -755,7 +875,10 @@ def __Logger__fatal(self, msg, *args):
         :param args: list of optional message arguments
         :type args: Sequence[str]
     """
-    self.__fatal(msg % args)
+    filename, line = get_source_location()
+    if args:
+        msg = msg % args
+    self.__fatal(filename, line, msg)
 
 
 def __UserDefaultAttrProp_set_enum_labels(self, enum_labels):
@@ -776,7 +899,7 @@ def __UserDefaultAttrProp_set_enum_labels(self, enum_labels):
 
 
 def __Attr__str(self):
-    return '%s(%s)' % (self.__class__.__name__, self.get_name())
+    return f'{self.__class__.__name__}({self.get_name()})'
 
 
 def __init_Attr():
@@ -2178,19 +2301,19 @@ def __doc_WAttribute():
         :rtype: int
     """)
 
-    #    document_method("set_write_value", """
-    #    set_write_value(self, data, dim_x = 1, dim_y = 0)
-    #
-    #        Set the writable attribute value.
-    #
-    #        :param data: the data to be set. Data must be compatible with the attribute type and format.
-    #                     for SPECTRUM and IMAGE attributes, data can be any type of sequence of elements
-    #                     compatible with the attribute type
-    #        :param dim_x: the attribute set value x length. Default value is 1
-    #        :type dim_x: int
-    #        :param dim_y: the attribute set value y length. Default value is 0
-    #        :type dim_y: int
-    #    """)
+    document_method("set_write_value", """
+    set_write_value(self, data, dim_x = 1, dim_y = 0)
+    
+       Set the writable attribute value.
+    
+       :param data: the data to be set. Data must be compatible with the attribute type and format.
+                    for SPECTRUM and IMAGE attributes, data can be any type of sequence of elements
+                    compatible with the attribute type
+       :param dim_x: optional, the attribute set value x length
+       :type dim_x: int
+       :param dim_y: optional, the attribute set value y length
+       :type dim_y: int
+    """)
 
     document_method("get_write_value", """
     get_write_value(self, lst)  <= DEPRECATED
