@@ -13,7 +13,7 @@
 This is an internal PyTango module.
 """
 
-__all__ = ["encoded_attribute_init"]
+__all__ = ("encoded_attribute_init",)
 
 __docformat__ = "restructuredtext"
 
@@ -27,7 +27,7 @@ if constants.NUMPY_SUPPORT:
         import numpy
 
         np = numpy
-    except:
+    except Exception:
         np = None
 else:
     np = None
