@@ -9,7 +9,7 @@
 # See LICENSE.txt for more info.
 # ------------------------------------------------------------------------------
 
-__all__ = ['PipeConfig']
+__all__ = ('PipeConfig',)
 
 from ._tango import Pipe, PipeWriteType, UserDefaultPipeProp, \
     CmdArgType, DevState, DispLevel, constants
@@ -19,7 +19,7 @@ from .utils import scalar_to_array_type, TO_TANGO_TYPE, \
 from .utils import document_method as __document_method
 
 
-class PipeConfig(object):
+class PipeConfig:
     """
     This class represents the python interface for the Tango IDL
     object PipeConfig."""
@@ -63,8 +63,8 @@ def __get_pipe_type_numpy_support(obj):
     except AttributeError:
         return __get_pipe_type_simple(obj)
     if ndim > 1:
-        raise TypeError('cannot translate numpy array with {0} '
-                        'dimensions to tango type'.format(obj.ndim))
+        raise TypeError(f'cannot translate numpy array with {obj.ndim} '
+                        f'dimensions to tango type')
     tg_type = TO_TANGO_TYPE[dtype]
     if ndim > 0:
         tg_type = scalar_to_array_type(dtype)
