@@ -11,17 +11,10 @@
 
 """Server helper classes for writing Tango device servers."""
 
-from __future__ import with_statement
-from __future__ import print_function
-from __future__ import absolute_import
 
 import sys
 import copy
-import enum
-try:
-    from inspect import getfullargspec as inspect_getargspec  # python 3.0+
-except ImportError:
-    from inspect import getargspec as inspect_getargspec
+from inspect import getfullargspec
 import inspect
 import logging
 import functools
@@ -33,10 +26,10 @@ from ._tango import DevFailed, GreenMode, SerialModel
 from .attr_data import AttrData
 from .pipe_data import PipeData
 from .device_class import DeviceClass
-from .device_server import LatestDeviceImpl, get_worker, set_worker
+from .device_server import LatestDeviceImpl, get_worker, set_worker, run_in_executor
 from .utils import get_enum_labels
-from .utils import is_seq, is_non_str_seq
-from .utils import scalar_to_array_type, TO_TANGO_TYPE
+from .utils import is_seq, is_non_str_seq, is_pure_str, is_enum_seq, is_enum, set_complex_value
+from .utils import is_devstate, is_devstate_seq, scalar_to_array_type, TO_TANGO_TYPE
 from .green import get_green_mode, get_executor
 from .pyutil import Util
 
@@ -48,15 +41,21 @@ API_VERSION = 2
 
 # Helpers
 
-def _get_tango_type_format(dtype=None, dformat=None):
+def _get_tango_type_format(dtype=None, dformat=None, caller=None):
     if dformat is None:
         dformat = AttrDataFormat.SCALAR
         if is_non_str_seq(dtype):
-            dtype = dtype[0]
-            dformat = AttrDataFormat.SPECTRUM
-            if is_non_str_seq(dtype):
+            if len(dtype):
                 dtype = dtype[0]
-                dformat = AttrDataFormat.IMAGE
+                dformat = AttrDataFormat.SPECTRUM
+                if is_non_str_seq(dtype):
+                    if len(dtype):
+                        dtype = dtype[0]
+                        dformat = AttrDataFormat.IMAGE
+                    elif caller == 'attribute':
+                        raise TypeError('Image attribute type must be specified as ((<dtype>,),)')
+            elif caller == 'attribute':
+                raise TypeError('Spectrum attribute type must be specified as (<dtype>,)')
     return TO_TANGO_TYPE[dtype], dformat
 
 
@@ -68,54 +67,43 @@ def from_typeformat_to_type(dtype, dformat):
     return scalar_to_array_type(dtype)
 
 
-def set_complex_value(attr, value):
-    is_tuple = isinstance(value, tuple)
-    dtype, fmt = attr.get_data_type(), attr.get_data_format()
-    if dtype == CmdArgType.DevEncoded:
-        if is_tuple and len(value) == 4:
-            attr.set_value_date_quality(*value)
-        elif is_tuple and len(value) == 3 and is_non_str_seq(value[0]):
-            attr.set_value_date_quality(value[0][0],
-                                        value[0][1],
-                                        *value[1:])
-        else:
-            attr.set_value(*value)
-    else:
-        if is_tuple:
-            if len(value) == 3:
-                if fmt == AttrDataFormat.SCALAR:
-                    attr.set_value_date_quality(*value)
-                elif fmt == AttrDataFormat.SPECTRUM:
-                    if is_seq(value[0]):
-                        attr.set_value_date_quality(*value)
-                    else:
-                        attr.set_value(value)
-                else:
-                    if is_seq(value[0]) and is_seq(value[0][0]):
-                        attr.set_value_date_quality(*value)
-                    else:
-                        attr.set_value(value)
-            else:
-                attr.set_value(value)
-        else:
-            attr.set_value(value)
-
-
 def _get_wrapped_read_method(attribute, read_method):
-    read_args = inspect_getargspec(read_method)
+    """
+    Checks which signature has method.
+    If the read method has 1 argument, the method is wrapped into another method
+    which has correct parameter definition to make it work.
+
+    Additionally, we wrap it with executor, if needed.
+
+    :param attribute: the attribute data information
+    :type attribute: AttrData
+    :param read_method: read method
+    :type read_method: callable
+    """
+
+    read_args = getfullargspec(read_method)
     nb_args = len(read_args.args)
 
     green_mode = attribute.read_green_mode
 
-    if nb_args < 2:
-        if green_mode == GreenMode.Synchronous:
+    if nb_args < 1:  # plain methods do not have "self" argument
+        if green_mode:
             @functools.wraps(read_method)
             def read_attr(self, attr):
-                ret = read_method(self)
+                worker = get_worker()
+                ret = worker.execute(read_method)
                 if not attr.get_value_flag() and ret is not None:
                     set_complex_value(attr, ret)
                 return ret
         else:
+            @functools.wraps(read_method)
+            def read_attr(self, attr):
+                ret = read_method()
+                if not attr.get_value_flag() and ret is not None:
+                    set_complex_value(attr, ret)
+                return ret
+    else:
+        if green_mode:
             @functools.wraps(read_method)
             def read_attr(self, attr):
                 worker = get_worker()
@@ -123,24 +111,20 @@ def _get_wrapped_read_method(attribute, read_method):
                 if not attr.get_value_flag() and ret is not None:
                     set_complex_value(attr, ret)
                 return ret
-    else:
-        if green_mode == GreenMode.Synchronous:
-            read_attr = read_method
         else:
             @functools.wraps(read_method)
             def read_attr(self, attr):
-                return get_worker().execute(read_method, self, attr)
+                ret = read_method(self)
+                if not attr.get_value_flag() and ret is not None:
+                    set_complex_value(attr, ret)
+                return ret
 
     return read_attr
 
 
 def __patch_read_method(tango_device_klass, attribute):
     """
-    Checks if method given by it's name for the given DeviceImpl
-    class has the correct signature. If a read/write method doesn't
-    have a parameter (the traditional Attribute), then the method is
-    wrapped into another method which has correct parameter definition
-    to make it work.
+    Finds read method for attribute, wraps it with executor and adds wrapped method to device dict.
 
     :param tango_device_klass: a DeviceImpl class
     :type tango_device_klass: class
@@ -149,42 +133,58 @@ def __patch_read_method(tango_device_klass, attribute):
     """
     read_method = getattr(attribute, "fget", None)
     if read_method:
-        method_name = "__read_{0}__".format(attribute.attr_name)
+        method_name = f"__read_{attribute.attr_name}__"
         attribute.read_method_name = method_name
     else:
         method_name = attribute.read_method_name
         read_method = getattr(tango_device_klass, method_name)
 
     read_attr = _get_wrapped_read_method(attribute, read_method)
-    method_name = "__read_{0}_wrapper__".format(attribute.attr_name)
+    method_name = f"__read_{attribute.attr_name}_wrapper__"
     attribute.read_method_name = method_name
 
     setattr(tango_device_klass, method_name, read_attr)
 
 
 def _get_wrapped_write_method(attribute, write_method):
+    """
+    Wraps write method with executor, if needed.
+    """
+    read_args = getfullargspec(write_method)
+    nb_args = len(read_args.args)
+
     green_mode = attribute.write_green_mode
 
-    if green_mode == GreenMode.Synchronous:
-        @functools.wraps(write_method)
-        def write_attr(self, attr):
-            value = attr.get_write_value()
-            return write_method(self, value)
+    if nb_args < 2:  # plain methods do not have "self" argument
+        if green_mode:
+            @functools.wraps(write_method)
+            def write_attr(self, attr):
+                value = attr.get_write_value()
+                return get_worker().execute(write_method, value)
+        else:
+            @functools.wraps(write_method)
+            def write_attr(self, attr):
+                value = attr.get_write_value()
+                return write_method(value)
+
     else:
-        @functools.wraps(write_method)
-        def write_attr(self, attr):
-            value = attr.get_write_value()
-            return get_worker().execute(write_method, self, value)
+        if green_mode:
+            @functools.wraps(write_method)
+            def write_attr(self, attr):
+                value = attr.get_write_value()
+                return get_worker().execute(write_method, self, value)
+        else:
+            @functools.wraps(write_method)
+            def write_attr(self, attr):
+                value = attr.get_write_value()
+                return write_method(self, value)
+
     return write_attr
 
 
 def __patch_write_method(tango_device_klass, attribute):
     """
-    Checks if method given by it's name for the given DeviceImpl
-    class has the correct signature. If a read/write method doesn't
-    have a parameter (the traditional Attribute), then the method is
-    wrapped into another method which has correct parameter definition
-    to make it work.
+    Finds write method for attribute, wraps it with executor and adds wrapped method to device dict.
 
     :param tango_device_klass: a DeviceImpl class
     :type tango_device_klass: class
@@ -193,7 +193,7 @@ def __patch_write_method(tango_device_klass, attribute):
     """
     write_method = getattr(attribute, "fset", None)
     if write_method:
-        method_name = "__write_{0}__".format(attribute.attr_name)
+        method_name = f"__write_{attribute.attr_name}__"
         attribute.write_method_name = method_name
     else:
         method_name = attribute.write_method_name
@@ -203,12 +203,79 @@ def __patch_write_method(tango_device_klass, attribute):
     setattr(tango_device_klass, method_name, write_attr)
 
 
+def _get_wrapped_isallowed_method(attribute, isallowed_method):
+    """
+    Checks which signature has method.
+    If the isallosed method has 1 argument, the method is wrapped into another method
+    which has correct parameter definition to make it work.
+
+    Additionally, we wrap it with executor, if needed.
+
+    :param attribute: the attribute data information
+    :type attribute: AttrData
+    :param isallowed_method: is allowed method
+    :type isallowed_method: callable
+    """
+
+    isallowed_args = getfullargspec(isallowed_method)
+    nb_args = len(isallowed_args.args)
+
+    green_mode = attribute.isallowed_green_mode
+    if nb_args < 2:  # plain methods do not have "self" argument
+        if green_mode:
+            @functools.wraps(isallowed_method)
+            def isallowed_attr(self, request):
+                worker = get_worker()
+                return worker.execute(isallowed_method, request)
+        else:
+            @functools.wraps(isallowed_method)
+            def isallowed_attr(self, request):
+                return isallowed_method(request)
+    else:
+        if green_mode:
+            @functools.wraps(isallowed_method)
+            def isallowed_attr(self, request):
+                worker = get_worker()
+                return worker.execute(isallowed_method, self, request)
+        else:
+            isallowed_attr = isallowed_method
+
+    return isallowed_attr
+
+
+def __patch_isallowed_method(tango_device_klass, attribute):
+    """
+    Finds isallowed method for attribute, wraps it with executor and adds wrapped method to device dict.
+
+    :param tango_device_klass: a DeviceImpl class
+    :type tango_device_klass: class
+    :param attribute: the attribute data information
+    :type attribute: AttrData
+    """
+    isallowed_method = getattr(attribute, "fisallowed", None)
+    if isallowed_method:
+        method_name = f"__is_{attribute.attr_name}_allowed__"
+        attribute.is_allowed_name = method_name
+    else:
+        method_name = attribute.is_allowed_name
+        isallowed_method = getattr(tango_device_klass, method_name, None)
+
+    if isallowed_method:
+        isallowed_attr = _get_wrapped_isallowed_method(attribute, isallowed_method)
+        method_name = f"__is_{attribute.attr_name}_allowed_wrapper__"
+        attribute.is_allowed_name = method_name
+
+        setattr(tango_device_klass, method_name, isallowed_attr)
+
+
 def __patch_attr_methods(tango_device_klass, attribute):
     """
-    Checks if the read and write methods have the correct signature.
-    If a read/write method doesn't have a parameter (the traditional
-    Attribute), then the method is wrapped into another method to make
-    this work.
+    Finds read, write and isallowed methods for attribute, checks their signatures
+    and wraps into another method to make them work.
+
+    Also patch methods with green executor, if requested.
+
+    Finally, adds pathed methods to the device dict.
 
     :param tango_device_klass: a DeviceImpl class
     :type tango_device_klass: class
@@ -222,9 +289,11 @@ def __patch_attr_methods(tango_device_klass, attribute):
                                 AttrWriteType.READ_WRITE):
         __patch_write_method(tango_device_klass, attribute)
 
+    __patch_isallowed_method(tango_device_klass, attribute)
+
 
 def _get_wrapped_pipe_read_method(pipe, read_method):
-    read_args = inspect_getargspec(read_method)
+    read_args = getfullargspec(read_method)
     nb_args = len(read_args.args)
 
     green_mode = pipe.read_green_mode
@@ -271,14 +340,14 @@ def __patch_pipe_read_method(tango_device_klass, pipe):
     """
     read_method = getattr(pipe, "fget", None)
     if read_method:
-        method_name = "__read_{0}__".format(pipe.pipe_name)
+        method_name = f"__read_{pipe.pipe_name}__"
         pipe.read_method_name = method_name
     else:
         method_name = pipe.read_method_name
         read_method = getattr(tango_device_klass, method_name)
 
     read_pipe = _get_wrapped_pipe_read_method(pipe, read_method)
-    method_name = "__read_{0}_wrapper__".format(pipe.pipe_name)
+    method_name = f"__read_{pipe.pipe_name}_wrapper__"
     pipe.read_method_name = method_name
 
     setattr(tango_device_klass, method_name, read_pipe)
@@ -315,7 +384,7 @@ def __patch_pipe_write_method(tango_device_klass, pipe):
     """
     write_method = getattr(pipe, "fset", None)
     if write_method:
-        method_name = "__write_{0}__".format(pipe.pipe_name)
+        method_name = f"__write_{pipe.pipe_name}__"
         pipe.write_method_name = method_name
     else:
         method_name = pipe.write_method_name
@@ -342,6 +411,35 @@ def __patch_pipe_methods(tango_device_klass, pipe):
         __patch_pipe_write_method(tango_device_klass, pipe)
 
 
+def __patch_is_command_allowed_method(tango_device_klass, is_allowed_method, cmd_name):
+    """
+    :param tango_device_klass: a DeviceImpl class
+    :type tango_device_klass: class
+    :param is_allowed_method: a callable to check if command is allowed
+    :type is_allowed_method: callable
+    :param cmd_name: command name
+    :type cmd_name: str
+    """
+
+    method_name = getattr(is_allowed_method, '__name__', f'is_{cmd_name}_allowed')
+
+    method_args = getfullargspec(is_allowed_method)
+    nb_args = len(method_args.args)
+
+    if not nb_args:
+        @functools.wraps(is_allowed_method)
+        def method(self):
+            return is_allowed_method()
+    else:
+        method = is_allowed_method
+
+    method_name = f"__wrapped_{method_name}__"
+
+    setattr(tango_device_klass, method_name, run_in_executor(method))
+
+    return method_name
+
+
 def __patch_standard_device_methods(klass):
     # TODO allow to force non green mode
 
@@ -423,8 +521,7 @@ class _DeviceClass(DeviceClass):
 def __create_tango_deviceclass_klass(tango_device_klass, attrs=None):
     klass_name = tango_device_klass.__name__
     if not issubclass(tango_device_klass, (BaseDevice)):
-        msg = "{0} device must inherit from " \
-              "tango.server.Device".format(klass_name)
+        msg = f"{klass_name} device must inherit from tango.server.Device"
         raise Exception(msg)
 
     if attrs is None:
@@ -469,6 +566,17 @@ def __create_tango_deviceclass_klass(tango_device_klass, attrs=None):
             if hasattr(attr_obj, "__tango_command__"):
                 cmd_name, cmd_info = attr_obj.__tango_command__
                 cmd_list[cmd_name] = cmd_info
+                if "Is allowed" in cmd_info[2]:
+                    is_allowed_method = cmd_info[2]["Is allowed"]
+                else:
+                    is_allowed_method = f"is_{cmd_name}_allowed"
+
+                if is_pure_str(is_allowed_method):
+                    is_allowed_method = getattr(tango_device_klass, is_allowed_method, None)
+
+                if is_allowed_method is not None:
+                    cmd_info[2]["Is allowed"] = __patch_is_command_allowed_method(tango_device_klass,
+                                                                                  is_allowed_method, cmd_name)
 
     __patch_standard_device_methods(tango_device_klass)
 
@@ -589,7 +697,7 @@ class BaseDevice(LatestDeviceImpl):
                 # Call this method in a try/except in case this is called
                 # during the DS shutdown sequence
                 ds_class = self.get_device_class()
-            except:
+            except Exception:
                 return
         try:
             pu = self.prop_util = ds_class.prop_util
@@ -608,7 +716,7 @@ class BaseDevice(LatestDeviceImpl):
                 properties = self.device_property_list[prop_name]
                 mandatory = properties[3]
                 if mandatory and value is None:
-                    msg = "Device property {0} is mandatory ".format(prop_name)
+                    msg = f"Device property {prop_name} is mandatory "
                     raise Exception(msg)
         except DevFailed as df:
             print(80 * "-")
@@ -715,9 +823,10 @@ class attribute(AttrData):
     archive_abs_change     :obj:`str`                       None
     archive_rel_change     :obj:`str`                       None
     archive_period         :obj:`str`                       None
-    green_mode             :obj:`~tango.GreenMode`          None                                    green mode for read and write. None means use server green mode.
-    read_green_mode        :obj:`~tango.GreenMode`          None                                    green mode for read. None means use server green mode.
-    write_green_mode       :obj:`~tango.GreenMode`          None                                    green mode for write. None means use server green mode.
+    green_mode             :obj:`bool`                      True                                    Default green mode for read/write/isallowed functions. If True: run with green mode executor, if False: run directly
+    read_green_mode        :obj:`bool`                      'green_mode' value                      green mode for read function. If True: run with green mode executor, if False: run directly
+    write_green_mode       :obj:`bool`                      'green_mode' value                      green mode for write function. If True: run with green mode executor, if False: run directly
+    isallowed_green_mode   :obj:`bool`                      'green_mode' value                      green mode for is allowed function. If True: run with green mode executor, if False: run directly
     forwarded              :obj:`bool`                      False                                   the attribute should be forwarded if True
     ===================== ================================ ======================================= =======================================================================================
 
@@ -782,6 +891,10 @@ class attribute(AttrData):
             green_mode = kwargs.pop("green_mode", True)
             self.read_green_mode = kwargs.pop("read_green_mode", green_mode)
             self.write_green_mode = kwargs.pop("write_green_mode", green_mode)
+            self.isallowed_green_mode = kwargs.pop("isallowed_green_mode", green_mode)
+
+            if not fget:
+                fget = kwargs.pop("fread", None)
 
             if fget:
                 if inspect.isroutine(fget):
@@ -790,25 +903,48 @@ class attribute(AttrData):
                         if fget.__doc__ is not None:
                             kwargs['doc'] = fget.__doc__
                 kwargs['fget'] = fget
-        super(attribute, self).__init__(self.name, class_name)
+
+            fset = kwargs.pop("fwrite", kwargs.pop("fset", None))
+            if fset:
+                if inspect.isroutine(fset):
+                    self.fset = fset
+                kwargs['fset'] = fset
+
+            fisallowed = kwargs.pop("fisallowed", None)
+            if fisallowed:
+                if inspect.isroutine(fisallowed):
+                    self.fisallowed = fisallowed
+                kwargs['fisallowed'] = fisallowed
+
+        super().__init__(self.name, class_name)
         self.__doc__ = kwargs.get('doc', kwargs.get('description',
                                                     'TANGO attribute'))
         if 'dtype' in kwargs:
             dtype = kwargs['dtype']
             dformat = kwargs.get('dformat')
-            if inspect.isclass(dtype) and issubclass(dtype, enum.Enum):
-                if dformat and dformat != AttrDataFormat.SCALAR:
-                    raise TypeError("DevEnum types can only be scalar, not {0}."
-                                    .format(dformat))
+            if is_enum(dtype) or is_enum_seq(dtype):
                 enum_labels = kwargs.get('enum_labels')
                 if enum_labels:
-                    raise TypeError("For dtype of enum.Enum the enum_labels must not "
-                                    "be specified - dtype: {0}, enum_labels: {1}."
-                                    .format(dtype, enum_labels))
-                kwargs['enum_labels'] = get_enum_labels(dtype)
+                    raise TypeError("For dtype of enum.Enum, (enum.Enum,) or ((enum.Enum,),) the enum_labels must not "
+                                    f"be specified - dtype: {dtype}, enum_labels: {enum_labels}.")
+                _dtype = dtype
                 dtype = CmdArgType.DevEnum
-            kwargs['dtype'], kwargs['dformat'] = \
-                _get_tango_type_format(dtype, dformat)
+
+                while is_enum_seq(_dtype):
+                    _dtype = _dtype[0]
+                    dtype = (dtype,)
+
+                kwargs['enum_labels'] = get_enum_labels(_dtype)
+
+            elif is_devstate(dtype) or is_devstate_seq(dtype):
+                _dtype = dtype
+                dtype = CmdArgType.DevState
+
+                while is_devstate_seq(_dtype):
+                    _dtype = _dtype[0]
+                    dtype = (dtype,)
+
+            kwargs['dtype'], kwargs['dformat'] = _get_tango_type_format(dtype, dformat, caller='attribute')
         self.build_from_dict(kwargs)
 
     def get_attribute(self, obj):
@@ -832,9 +968,9 @@ class attribute(AttrData):
 
     def setter(self, fset):
         """
-        To be used as a decorator. Will define the decorated method
-        as a write attribute method to be called when client writes
-        the attribute
+        To be used as a decorator, ``@attribute.setter``. Defines the decorated method
+        as the write attribute method to be called when a client writes
+        the attribute. Equivalent to ``@attribute.write``.
         """
         self.fset = fset
         if self.attr_write == AttrWriteType.READ:
@@ -846,12 +982,42 @@ class attribute(AttrData):
 
     def write(self, fset):
         """
-        To be used as a decorator. Will define the decorated method
-        as a write attribute method to be called when client writes
-        the attribute
+        To be used as a decorator, ``@attribute.write``. Defines the decorated method
+        as the write attribute method to be called when a client writes
+        the attribute. Equivalent to ``@attribute.setter``.
         """
         return self.setter(fset)
 
+    def getter(self, fget):
+        """
+        To be used as a decorator, ``@attribute.getter``. Defines the decorated method
+        as the read attribute method to be called when a client reads
+        the attribute. Equivalent to ``@attribute.read``.
+        """
+        self.fget = fget
+        if self.attr_write == AttrWriteType.WRITE:
+            if getattr(self, 'fset', None):
+                self.attr_write = AttrWriteType.READ_WRITE
+            else:
+                self.attr_write = AttrWriteType.READ
+        return self
+
+    def read(self, fget):
+        """
+        To be used as a decorator, ``@attribute.read``. Defines the decorated method
+        as the read attribute method to be called when a client reads
+        the attribute. Equivalent to ``@attribute.getter``.
+        """
+        return self.getter(fget)
+
+    def is_allowed(self, fisallowed):
+        """
+        To be used as a decorator, ``@attribute.is_allowed``. Defines the decorated
+        method as the is allowed attribute method
+        """
+        self.fisallowed = fisallowed
+        return self
+
     def __call__(self, fget):
         return type(self)(fget=fget, **self._kwargs)
 
@@ -954,6 +1120,7 @@ class pipe(PipeData):
         green_mode = kwargs.pop("green_mode", True)
         self.read_green_mode = kwargs.pop("read_green_mode", green_mode)
         self.write_green_mode = kwargs.pop("write_green_mode", green_mode)
+        self.isallowed_green_mode = kwargs.pop("isallowed_green_mode", green_mode)
 
         if fget:
             if inspect.isroutine(fget):
@@ -963,7 +1130,7 @@ class pipe(PipeData):
                         kwargs['doc'] = fget.__doc__
             kwargs['fget'] = fget
 
-        super(pipe, self).__init__(name, class_name)
+        super().__init__(name, class_name)
         self.__doc__ = kwargs.get('doc', kwargs.get('description',
                                                     'TANGO pipe'))
         self.build_from_dict(kwargs)
@@ -1006,9 +1173,9 @@ class pipe(PipeData):
 
 
 def __build_command_doc(f, name, dtype_in, doc_in, dtype_out, doc_out):
-    doc = "'{0}' TANGO command".format(name)
+    doc = f"'{name}' TANGO command"
     if dtype_in is not None:
-        arg_spec = inspect_getargspec(f)
+        arg_spec = getfullargspec(f)
         if len(arg_spec.args) > 1:
             # arg[0] should be self and arg[1] the command argument
             param_name = arg_spec.args[1]
@@ -1018,27 +1185,26 @@ def __build_command_doc(f, name, dtype_in, doc_in, dtype_out, doc_out):
         if not isinstance(dtype_in, str):
             try:
                 dtype_in_str = dtype_in.__name__
-            except:
+            except Exception:
                 pass
         msg = doc_in or '(not documented)'
-        doc += '\n\n:param {0}: {1}\n:type {0}: {2}'.format(
-            param_name, msg, dtype_in_str)
+        doc += f'\n\n:param {param_name}: {msg}\n:type {param_name}: {dtype_in_str}'
     if dtype_out is not None:
         dtype_out_str = str(dtype_out)
         if not isinstance(dtype_out, str):
             try:
                 dtype_out_str = dtype_out.__name__
-            except:
+            except Exception:
                 pass
         msg = doc_out or '(not documented)'
-        doc += '\n\n:return: {0}\n:rtype: {1}'.format(msg, dtype_out_str)
+        doc += f'\n\n:return: {msg}\n:rtype: {dtype_out_str}'
     return doc
 
 
 def command(f=None, dtype_in=None, dformat_in=None, doc_in="",
             dtype_out=None, dformat_out=None, doc_out="",
             display_level=None, polling_period=None,
-            green_mode=None):
+            green_mode=None, fisallowed=None):
     """
     Declares a new tango command in a :class:`Device`.
     To be used like a decorator in the methods you want to declare as
@@ -1093,12 +1259,17 @@ def command(f=None, dtype_in=None, dformat_in=None, doc_in="",
         set green mode on this specific command. Default value is None meaning
         use the server green mode. Set it to GreenMode.Synchronous to force
         a non green command in a green server.
+    :param fisallowed: is allowed method for command
+    :type fisallowed: str or callable
 
     .. versionadded:: 8.1.7
         added green_mode option
 
     .. versionadded:: 9.2.0
         added display_level and polling_period optional argument
+
+    .. versionadded:: 9.4.0
+        added fisallowed option
     """
     if f is None:
         return functools.partial(
@@ -1106,7 +1277,7 @@ def command(f=None, dtype_in=None, dformat_in=None, doc_in="",
             dtype_in=dtype_in, dformat_in=dformat_in, doc_in=doc_in,
             dtype_out=dtype_out, dformat_out=dformat_out, doc_out=doc_out,
             display_level=display_level, polling_period=polling_period,
-            green_mode=green_mode)
+            green_mode=green_mode, fisallowed=fisallowed)
     name = f.__name__
 
     dtype_format_in = _get_tango_type_format(dtype_in, dformat_in)
@@ -1120,6 +1291,8 @@ def command(f=None, dtype_in=None, dformat_in=None, doc_in="",
         config_dict['Display level'] = display_level
     if polling_period is not None:
         config_dict['Polling period'] = polling_period
+    if fisallowed is not None:
+        config_dict['Is allowed'] = fisallowed
 
     if green_mode == GreenMode.Synchronous:
         cmd = f
@@ -1141,7 +1314,7 @@ def command(f=None, dtype_in=None, dformat_in=None, doc_in="",
     return cmd
 
 
-class _BaseProperty(object):
+class _BaseProperty:
     def __init__(self, dtype, doc='', default_value=None, update_db=False):
         self.name = None
         dtype = from_typeformat_to_type(*_get_tango_type_format(dtype))
@@ -1195,8 +1368,7 @@ class device_property(_BaseProperty):
     """
     def __init__(self, dtype, doc='', mandatory=False,
                  default_value=None, update_db=False):
-        super(device_property, self).__init__(dtype, doc, default_value,
-                                              update_db)
+        super().__init__(dtype, doc, default_value, update_db)
         self.mandatory = mandatory
         if mandatory and default_value is not None:
             msg = ("Invalid arguments: 'mandatory' is True, so 'default_value' must be None. "
@@ -1317,8 +1489,8 @@ def _get_class_green_mode(classes, green_mode):
         green_modes.add(device_green_mode)
     if len(green_modes) > 1:
         raise ValueError(
-            "Devices with mixed green modes cannot be run in the same device "
-            "server process. Modes: {}. Classes: {}.".format(green_modes, classes)
+            f"Devices with mixed green modes cannot be run in the same device "
+            f"server process. Modes: {green_modes}. Classes: {classes}."
         )
     elif len(green_modes) == 0:
         raise ValueError("No device classes specified - cannot run device server " 
@@ -1556,12 +1728,12 @@ def server_run(classes, args=None, msg_stream=sys.stdout,
                green_mode=green_mode)
 
 
-# Instanciate DeviceMeta using BaseDevice
-Device = DeviceMeta("Device", (BaseDevice,), {'__doc__': """\
+class Device(BaseDevice, metaclass=DeviceMeta):
+    """
     Device class for the high-level API.
 
-    All device specific classes should inherit from this class.
-    """})
+    All device-specific classes should inherit from this class.
+    """
 
 # Avoid circular imports
 from .tango_object import Server  # noqa: E402
