@@ -1,11 +1,9 @@
 """Provide a context to run a device without a database."""
 
-from __future__ import absolute_import
 
 # Imports
 import os
 import sys
-import six
 import time
 import struct
 import socket
@@ -13,11 +11,12 @@ import tempfile
 import traceback
 import collections
 from functools import partial
+import psutil
 
 # Concurrency imports
 import threading
 import multiprocessing
-from six.moves import queue
+import queue
 
 # CLI imports
 from ast import literal_eval
@@ -29,10 +28,20 @@ from .server import run
 from .utils import is_non_str_seq
 from . import DeviceProxy, Database, Util
 
-__all__ = ("MultiDeviceTestContext", "DeviceTestContext", "run_device_test_context")
+__all__ = ("MultiDeviceTestContext", "DeviceTestContext", "run_device_test_context",
+           "get_server_port_via_pid")
 
 # Helpers
 
+_WINDOWS = "nt" in os.name
+if not _WINDOWS:
+    _DEFAULT_THREAD_TIMEOUT = 3.
+    _DEFAULT_PROCESS_TIMEOUT = 5.
+else:
+    _DEFAULT_THREAD_TIMEOUT = 5.
+    _DEFAULT_PROCESS_TIMEOUT = 7.
+
+
 IOR = collections.namedtuple(
     'IOR',
     'first dtype_length dtype nb_profile tag '
@@ -40,7 +49,7 @@ IOR = collections.namedtuple(
 
 
 def ascii_to_bytes(s):
-    convert = lambda x: six.int2byte(int(x, 16))
+    convert = lambda x: bytes((int(x, 16),))
     return b''.join(convert(s[i:i + 2]) for i in range(0, len(s), 2))
 
 
@@ -48,9 +57,9 @@ def parse_ior(encoded_ior):
     assert encoded_ior[:4] == 'IOR:'
     ior = ascii_to_bytes(encoded_ior[4:])
     dtype_length = struct.unpack_from('II', ior)[-1]
-    form = 'II{:d}sIIIBBHI'.format(dtype_length)
+    form = f'II{dtype_length:d}sIIIBBHI'
     host_length = struct.unpack_from(form, ior)[-1]
-    form = 'II{:d}sIIIBBHI{:d}sH0I'.format(dtype_length, host_length)
+    form = f'II{dtype_length:d}sIIIBBHI{host_length:d}sH0I'
     values = struct.unpack_from(form, ior)
     values += (ior[struct.calcsize(form):],)
     strip = lambda x: x[:-1] if isinstance(x, bytes) else x
@@ -65,6 +74,99 @@ def get_server_host_port():
     return ior.host.decode(), ior.port
 
 
+def get_server_port_via_pid(pid, host):
+    """Return the TCP port that a device server process is listening on (GIOP).
+
+    This checks TCP sockets open on the process with the given PID, and attempts
+    to find the one that accepts GIOP traffic.  A connection will be made to each
+    listening socket, and data may be sent to them.
+
+    General Inter-ORB Protocol (GIOP) is the message protocol which object
+    request brokers (ORBs) communicate in CORBA.  This port is the one that is
+    used when connecting a DeviceProxy.  These are not the port(s) used for ZMQ
+    event traffic.
+
+    :param pid: operating system process identifier
+    :type pid: int
+    :param host: hostname/IP that device server is listening on.  E.g., 127.0.0.1,
+    IP address of a non-loopback network interface, etc.  Note that starting a device
+    server on "localhost" may fail if OmniORB creates an IPv6-only socket.
+    :type pid: str
+
+    :returns: TCP port number
+    :rtype: int
+
+    :raises RuntimeError: If the GIOP port couldn't be identified
+
+    .. versionadded:: 9.4.0
+    """
+    ports = _get_listening_tcp_ports(pid)
+    return _get_giop_port(host, ports)
+
+
+def _get_listening_tcp_ports(pid):
+    p = psutil.Process(pid)
+    conns = p.connections(kind="tcp")
+    return [c.laddr[1] for c in conns]
+
+
+def _get_giop_port(host, ports):
+    protocols = _try_get_protocols_on_ports(host, ports)
+    for port, protocol in protocols.items():
+        if protocol == "GIOP":
+            return port
+    raise RuntimeError(
+        f"None of ports {ports} appear to have GIOP protocol. "
+        f"Guessed protocols: {protocols}."
+    )
+
+
+def _try_get_protocols_on_ports(host, ports):
+    """Return a dict with port to protocol mapping.
+
+    This attempts to establish a TCP socket connection to the host
+    for each port, and then determine the protocol it supports.
+
+    ZMQ client sockets receive an unsolicited version check message on connection.
+    CORBA GIOP client sockets don't receive an unsolicited message, so we send
+    a requested to disconnect, and expect an empty message back.
+    """
+    zmq_response = b'\xff\x00\x00\x00\x00\x00\x00\x00\x01\x7f'  # signature + version check
+    giop_send = b'GIOP\x01\x02\x01\x05\x00\x00\x00\x00'  # request disconnect
+    giop_response = b''  # graceful disconnect
+    max_bytes_expected = len(zmq_response)
+
+    protocols = dict.fromkeys(ports, "Unknown")
+    for port in ports:
+        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        try:
+            sock.settimeout(0.001)
+            server_address = (host, port)
+            sock.connect(server_address)
+
+            try:
+                data = sock.recv(max_bytes_expected)
+                if data == zmq_response:
+                    protocols[port] = "ZMQ"
+                    continue
+            except OSError:
+                pass
+
+            try:
+                sock.sendall(giop_send)
+                data = sock.recv(max_bytes_expected)
+                if data == giop_response:
+                    protocols[port] = "GIOP"
+                    continue
+            except OSError:
+                pass
+        except OSError:
+            pass
+        finally:
+            sock.close()
+    return protocols
+
+
 def literal_dict(arg):
     return dict(literal_eval(arg))
 
@@ -75,9 +177,8 @@ def device(path):
     try:
         module = import_module(module_name)
     except Exception:
-        raise ArgumentTypeError("Error importing {0}.{1}:\n{2}"
-                                .format(module_name, device_name,
-                                        traceback.format_exc()))
+        raise ArgumentTypeError(f"Error importing {module_name}.{device_name}:\n"
+                                f"{traceback.format_exc()}")
     return getattr(module, device_name)
 
 
@@ -90,7 +191,10 @@ def get_host_ip():
     """
     s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
     # Connecting to a UDP address doesn't send packets
-    s.connect(('8.8.8.8', 0))
+    # Note:  For some reason Python3 on macOS does not accept 0 as a port but
+    # returns with an errno 49 instead. Therefore just use port 80 which just
+    # works as well.
+    s.connect(('8.8.8.8', 80))
     # Get ip address
     ip = s.getsockname()[0]
     return ip
@@ -117,7 +221,7 @@ def _device_class_from_field(field):
     return (device_cls_class, device_class)
 
 
-class MultiDeviceTestContext(object):
+class MultiDeviceTestContext:
     """Context to run device(s) without a database.
 
     The difference with respect to
@@ -251,8 +355,8 @@ class MultiDeviceTestContext(object):
     nodb = "dbase=no"
     command = "{0} {1} -ORBendPoint giop:tcp:{2}:{3} -file={4}"
 
-    thread_timeout = 3.
-    process_timeout = 5.
+    thread_timeout = _DEFAULT_THREAD_TIMEOUT
+    process_timeout = _DEFAULT_PROCESS_TIMEOUT
 
     def __init__(self, devices_info, server_name=None, instance_name=None,
                  db=None, host=None, port=0, debug=3,
@@ -287,7 +391,7 @@ class MultiDeviceTestContext(object):
         # Command args
         string = self.command.format(
             server_name, instance_name, host, port, db)
-        string += " -v{0}".format(debug) if debug else ""
+        string += f" -v{debug}" if debug else ""
         cmd_args = string.split()
 
         class_list = []
@@ -375,8 +479,8 @@ class MultiDeviceTestContext(object):
             device_name = info["name"]
             properties = info.get("properties", {})
             # Patch the property dict to avoid a PyTango bug
-            patched = dict((key, value if value != '' else ' ')
-                           for key, value in properties.items())
+            patched = {key: value if value != '' else ' '
+                           for key, value in properties.items()}
             db.put_device_property(device_name, patched)
 
             memorized = info.get("memorized", {})
@@ -393,16 +497,14 @@ class MultiDeviceTestContext(object):
         if self.handle is not None:
             os.close(self.handle)
             os.unlink(self.db)
-    
+
     def get_server_access(self):
         """Return the full server name."""
-        form = 'tango://{0}:{1}/{2}#{3}'
-        return form.format(self.host, self.port, self.server_name, self.nodb)
+        return f'tango://{self.host}:{self.port}/{self.server_name}#{self.nodb}'
 
     def get_device_access(self, device_name):
         """Return the full device name."""
-        form = 'tango://{0}:{1}/{2}#{3}'
-        return form.format(self.host, self.port, device_name, self.nodb)
+        return f'tango://{self.host}:{self.port}/{device_name}#{self.nodb}'
 
     def get_device(self, device_name):
         """Return the device proxy corresponding to the given device name.
@@ -431,17 +533,23 @@ class MultiDeviceTestContext(object):
                     'Check stdout/stderr for more information.')
             elif hasattr(self.thread, 'exitcode'):
                 raise RuntimeError(
-                    'The server process stopped with exitcode {}. '
-                    'Check stdout/stderr for more information.'
-                    ''.format(self.thread.exitcode))
+                    f'The server process stopped with exitcode {self.thread.exitcode}. '
+                    f'Check stdout/stderr for more information.')
             else:
                 raise RuntimeError(
                     'The server stopped without reporting. '
                     'Check stdout/stderr for more information.')
         try:
             self.host, self.port = args
-        except ValueError:
-            six.reraise(*args)
+        except ValueError as e:
+            # Warning: an assumption made here - if the args don't contain the
+            #          expected (host, port) items then we assume the args contain
+            #          exception info.
+            if len(args) == 3:
+                exc_type, exc_value, exc_traceback = args
+                raise exc_value
+            # In case the above assumption is wrong: re-raise the original exception
+            raise ValueError(*args) from e
         # Get server proxy
         self.server = DeviceProxy(self.get_server_access())
         self.server.ping()
@@ -553,7 +661,7 @@ class DeviceTestContext(MultiDeviceTestContext):
                 )
             },
         )
-        super(DeviceTestContext, self).__init__(devices_info,
+        super().__init__(devices_info,
                                                 server_name=server_name,
                                                 instance_name=instance_name,
                                                 db=db, host=host,
@@ -570,11 +678,11 @@ class DeviceTestContext(MultiDeviceTestContext):
         """Return the full device name."""
         if device_name is None:
             device_name = self.device_name
-        return super(DeviceTestContext, self).get_device_access(
+        return super().get_device_access(
             device_name)
 
     def connect(self):
-        super(DeviceTestContext, self).connect()
+        super().connect()
         # Get device proxy
         self.device = self.get_device(self.device_name)
         self.device.ping()
@@ -625,10 +733,10 @@ def run_device_test_context(args=None):
     context = DeviceTestContext(
         device, properties=properties, host=host, port=port, debug=debug)
     context.start()
-    msg = '{0} started on port {1} with properties {2}'
-    print(msg.format(device.__name__, context.port, properties))
-    print('Device access: {}'.format(context.get_device_access()))
-    print('Server access: {}'.format(context.get_server_access()))
+    msg = f'{device.__name__} started on port {context.port} with properties {properties}'
+    print(msg)
+    print(f'Device access: {context.get_device_access()}')
+    print(f'Server access: {context.get_server_access()}')
     context.join()
     print("Done")
 
