@@ -1,17 +1,15 @@
 """Test utilities"""
 
-import sys
-import six
 import enum
-try:
-    import collections.abc as collections_abc  # python 3.3+
-except ImportError:
-    import collections as collections_abc
+import numpy as np
 
 # Local imports
-from . import DevState, GreenMode
+from . import DevState, GreenMode, AttrDataFormat, ExtractAs
 from .server import Device
-from .test_context import MultiDeviceTestContext, DeviceTestContext
+from .test_context import (
+    MultiDeviceTestContext, DeviceTestContext, get_server_port_via_pid
+)
+from .utils import is_non_str_seq, FROM_TANGO_TO_NUMPY_TYPE
 from . import DeviceClass, LatestDeviceImpl, DevLong64, SCALAR, READ
 
 # Conditional imports
@@ -20,24 +18,23 @@ try:
 except ImportError:
     pytest = None
 
-try:
-    import numpy.testing
-except ImportError:
-    numpy = None
-
 __all__ = (
     'MultiDeviceTestContext',
     'DeviceTestContext',
     'SimpleDevice',
     'ClassicAPISimpleDeviceImpl',
-    'ClassicAPISimpleDeviceClass'
+    'ClassicAPISimpleDeviceClass',
+    'state',
+    'command_typed_values',
+    'attribute_typed_values',
+    'server_green_mode',
+    'attr_data_format',
+    'get_server_port_via_pid',
 )
 
-PY3 = sys.version_info >= (3,)
-
 # char \x00 cannot be sent in a DevString. All other 1-255 chars can
 ints = tuple(range(1, 256))
-bytes_devstring = bytes(ints) if PY3 else ''.join(map(chr, ints))
+bytes_devstring = bytes(ints)
 str_devstring = bytes_devstring.decode('latin-1')
 
 # Test devices
@@ -98,15 +95,39 @@ class BadEnumDuplicates(enum.IntEnum):
 # why you will find that all property related tests are truncated to
 # the first two values of the arrays below
 
-TYPED_VALUES = {
+GENERAL_TYPED_VALUES = {
     int: (1, 2, -65535, 23),
     float: (2.71, 3.14, -34.678e-10, 12.678e+15),
     str: ('hey hey', 'my my', bytes_devstring, str_devstring),
     bool: (False, True, True, False),
-    (int,): ([1, 2, 3], [9, 8, 7], [-65535, 2224], [0, 0]),
-    (float,): ([0.1, 0.2, 0.3], [0.9, 0.8, 0.7], [-6.3232e-3], [0.0, 12.56e+12]),
-    (str,): (['ab', 'cd', 'ef'], ['gh', 'ij', 'kl'], 10*[bytes_devstring], 10*[str_devstring]),
-    (bool,): ([False, False, True], [True, False, False], [False], [True])}
+    (int,): (np.array([1, 2]), [1, 2, 3], [9, 8, 7], [-65535, 2224], [0, 0], ),
+    (float,): (np.array([0.1, 0.2]), [0.1, 0.2, 0.3], [0.9, 0.8, 0.7], [-6.3232e-3], [0.0, 12.56e+12]),
+    (str,): (np.array(['foo', 'bar']), ['ab', 'cd', 'ef'], ['gh', 'ij', 'kl'], 10*[bytes_devstring], 10*[str_devstring]),
+    (bool,): (np.array([True, False]), [False, False, True], [True, False, False], [False], [True]),
+}
+
+IMAGE_TYPED_VALUES = {
+    ((int,),): (np.vstack((np.array([1, 2]), np.array([3, 4]))),
+                [[1, 2, 3], [4, 5, 6]], [[-65535, 2224], [-65535, 2224]],),
+    ((float,),): (np.vstack((np.array([0.1, 0.2]), np.array([0.3, 0.4]))),
+                  [[0.1, 0.2, 0.3], [0.9, 0.8, 0.7]], [[-6.3232e-3, 0.0], [0.0, 12.56e+12]],),
+    ((str,),): (np.vstack((np.array(['hi-hi', 'ha-ha']), np.array(['hu-hu', 'yuhuu']))),
+                [['ab', 'cd', 'ef'], ['gh', 'ij', 'kl']], [10*[bytes_devstring],10*[bytes_devstring]],
+                [10*[str_devstring], 10*[str_devstring]],),
+    ((bool,),): (np.vstack((np.array([True, False]), np.array([False, True]))),
+                 [[False, False, True], [True, False, False]], [[False]], [[True]],)
+}
+
+
+EXTRACT_AS = [(ExtractAs.Numpy, np.ndarray),
+              (ExtractAs.Tuple, tuple),
+              (ExtractAs.List, list),
+              (ExtractAs.Bytes, bytes),
+              (ExtractAs.ByteArray, bytearray),
+              (ExtractAs.String, str)
+              ]
+
+BASE_TYPES = [float, int, str, bool]
 
 # these sets to test Device Server input arguments
 
@@ -115,13 +136,13 @@ OS_SYSTEMS = ['linux', 'win']
 #    os_system, in string, out arguments list, raised exception
 DEVICE_SERVER_ARGUMENTS = (
     (['linux', 'win'], 'MyDs instance --nodb --port 1234',
-     ['MyDs', 'instance', '-nodb', '-ORBendPoint', 'giop:tcp::1234']),
+     ['MyDs', 'instance', '-nodb', '-ORBendPoint', 'giop:tcp:0.0.0.0:1234']),
     (['linux', 'win'], 'MyDs -port 1234 -host myhost instance',
      ['MyDs', 'instance', '-ORBendPoint', 'giop:tcp:myhost:1234']),
     (['linux', 'win'], 'MyDs instance --ORBendPoint giop:tcp::1234',
      ['MyDs', 'instance', '-ORBendPoint', 'giop:tcp::1234']),
     (['linux', 'win'], 'MyDs instance -nodb -port 1000 -dlist a/b/c;d/e/f',
-     ['MyDs', 'instance', '-ORBendPoint', 'giop:tcp::1000', '-nodb', '-dlist', 'a/b/c;d/e/f']),
+     ['MyDs', 'instance', '-ORBendPoint', 'giop:tcp:0.0.0.0:1000', '-nodb', '-dlist', 'a/b/c;d/e/f']),
     (['linux', 'win'], 'MyDs instance -file a/b/c',
      ['MyDs', 'instance', '-file=a/b/c']),
     ([], 'MyDs instance -nodb', []),  # this test should always fail
@@ -147,55 +168,90 @@ DEVICE_SERVER_ARGUMENTS = (
 )
 
 def repr_type(x):
-    if not isinstance(x, tuple):
-        return x.__name__
-    return '({},)'.format(x[0].__name__)
+    if isinstance(x, (list, tuple)):
+        return f'({repr_type(x[0])},)'
+    return f'{x.__name__}'
 
 
 # Numpy helpers
 
-if numpy and pytest:
-
-    def assert_close(a, b):
-        if isinstance(a, six.string_types):
-            assert a == b
-            return
-        if isinstance(a, collections_abc.Sequence) and len(a) and isinstance(a[0], six.string_types):
-            assert list(a) == list(b)
-            return
-        try:
-            assert a == pytest.approx(b)
-        except ValueError:
-            numpy.testing.assert_allclose(a, b)
-
-# Pytest fixtures
-
 if pytest:
 
-    def create_result(dtype, value):
-        if dtype == str:
-            if PY3:
-                if isinstance(value, six.binary_type):
-                    return value.decode('latin-1')
-            else:
-                if isinstance(value, six.text_type):
-                    return value.encode('latin-1')
-        elif dtype == (str,):
-            return [create_result(str, v) for v in value]
+    def __assert_all_types(a, b):
+        if isinstance(a, str):
+            assert a == b
+            return
+
+        try:
+            assert a == pytest.approx(b)
+        except (ValueError, TypeError):
+            np.testing.assert_allclose(a, b)
+
+    def assert_close(a, b):
+        if is_non_str_seq(a):
+            assert len(a) == len(b)
+            for _a, _b in zip(a, b):
+                assert_close(_a, _b)
+        else:
+            __assert_all_types(a, b)
+
+
+    def __convert_value(value):
+        if isinstance(value, bytes):
+            return value.decode('latin-1')
         return value
 
+    def create_result(dtype, value):
+        if isinstance(dtype, (list, tuple)):
+            dtype = dtype[0]
+            return [create_result(dtype, v) for v in value]
+
+        return __convert_value(value)
+
+    def convert_to_type(value, attr_type, expected_type):
+        if expected_type in [tuple, list]:
+            return expected_type(value)
+        elif expected_type == np.ndarray:
+            return np.array(value, dtype=FROM_TANGO_TO_NUMPY_TYPE[attr_type])
+        elif expected_type in [bytes, bytearray, str]:
+            value = np.array(value, dtype=FROM_TANGO_TO_NUMPY_TYPE[attr_type]).tobytes()
+            if expected_type == bytearray:
+                return bytearray(value)
+            elif expected_type == str:
+                return "".join([chr(b) for b in value])
+            return value
+        else:
+            pytest.xfail("Unknown extract_as type")
+
     @pytest.fixture(params=DevState.values.values())
     def state(request):
         return request.param
 
     @pytest.fixture(
-        params=list(TYPED_VALUES.items()),
+        params=list(GENERAL_TYPED_VALUES.items()),
         ids=lambda x: repr_type(x[0]))
-    def typed_values(request):
+    def command_typed_values(request):
         dtype, values = request.param
         expected = lambda v: create_result(dtype, v)
         return dtype, values, expected
 
+    @pytest.fixture(
+        params=list({**GENERAL_TYPED_VALUES, **IMAGE_TYPED_VALUES}.items()),
+        ids=lambda x: repr_type(x[0]))
+    def attribute_typed_values(request):
+        dtype, values = request.param
+        expected = lambda v: create_result(dtype, v)
+        return dtype, values, expected
+
+    @pytest.fixture(params=EXTRACT_AS, ids=[f"extract_as.{req_type}" for req_type, _ in EXTRACT_AS])
+    def extract_as(request):
+        requested_type, expected_type = request.param
+        return requested_type, expected_type
+
+    @pytest.fixture(params=BASE_TYPES)
+    def base_type(request):
+        return request.param
+
     @pytest.fixture(params=GreenMode.values.values())
     def green_mode(request):
         return request.param
@@ -207,9 +263,9 @@ if pytest:
     def server_green_mode(request):
         return request.param
 
-    @pytest.fixture(params=['linux', 'win'])
-    def os_system(request):
-        original_platform = sys.platform
-        sys.platform = request.param
-        yield
-        sys.platform = original_platform
+    @pytest.fixture(params=[
+        AttrDataFormat.SCALAR,
+        AttrDataFormat.SPECTRUM,
+        AttrDataFormat.IMAGE])
+    def attr_data_format(request):
+        return request.param
