@@ -13,22 +13,19 @@
 This is an internal PyTango module.
 """
 
-from __future__ import with_statement
-from __future__ import print_function
 
 import os
 import sys
-import six
 import types
 import numbers
+import inspect
 import enum
+import numpy
 
 from argparse import HelpFormatter
+from packaging.version import Version
 
-try:
-    import collections.abc as collections_abc  # python 3.3+
-except ImportError:
-    import collections as collections_abc
+import collections.abc
 
 from ._tango import StdStringVector, StdDoubleVector, \
     DbData, DbDatum, DbDevInfos, DbDevExportInfos, CmdArgType, AttrDataFormat, \
@@ -47,7 +44,7 @@ __all__ = (
     "is_str_type", "obj_2_str", "seqStr_2_obj",
     "scalar_to_array_type",
     "document_method", "document_static_method", "document_enum",
-    "CaselessList", "CaselessDict", "EventCallBack", "get_home",
+    "CaselessList", "CaselessDict", "EventCallback", "get_home",
     "from_version_str_to_hex_str", "from_version_str_to_int",
     "seq_2_StdStringVector", "StdStringVector_2_seq",
     "dir2", "TO_TANGO_TYPE", "ensure_binary")
@@ -122,6 +119,21 @@ _binary_types = (
     CmdArgType.DevVarCharArray,)
 
 
+FROM_TANGO_TO_NUMPY_TYPE = {
+    CmdArgType.DevBoolean: numpy.bool_,
+    CmdArgType.DevUChar: numpy.ubyte,
+    CmdArgType.DevShort: numpy.short,
+    CmdArgType.DevUShort: numpy.ushort,
+    CmdArgType.DevLong: numpy.int32,
+    CmdArgType.DevULong: numpy.uint32,
+    CmdArgType.DevLong64: numpy.int64,
+    CmdArgType.DevULong64: numpy.uint64,
+    CmdArgType.DevString: str,
+    CmdArgType.DevDouble: numpy.float64,
+    CmdArgType.DevFloat: numpy.float32,
+}
+
+
 def __build_to_tango_type():
     ret = {
         int: CmdArgType.DevLong64,
@@ -170,22 +182,6 @@ def __build_to_tango_type():
             value = getattr(CmdArgType, key)
             ret[key] = ret[value] = value
 
-    if constants.NUMPY_SUPPORT:
-        import numpy
-        FROM_TANGO_TO_NUMPY_TYPE = {
-            CmdArgType.DevBoolean: numpy.bool8,
-            CmdArgType.DevUChar: numpy.ubyte,
-            CmdArgType.DevShort: numpy.short,
-            CmdArgType.DevUShort: numpy.ushort,
-            CmdArgType.DevLong: numpy.int32,
-            CmdArgType.DevULong: numpy.uint32,
-            CmdArgType.DevLong64: numpy.int64,
-            CmdArgType.DevULong64: numpy.uint64,
-            CmdArgType.DevString: str,
-            CmdArgType.DevDouble: numpy.float64,
-            CmdArgType.DevFloat: numpy.float32,
-        }
-
         for key, value in FROM_TANGO_TO_NUMPY_TYPE.items():
             ret[value] = key
     return ret
@@ -220,7 +216,6 @@ __device_classes = None
 
 bool_ = lambda value_str: value_str.lower() == "true"
 
-
 def __import(name):
     __import__(name)
     return sys.modules[name]
@@ -228,36 +223,31 @@ def __import(name):
 
 def __requires(package_name, min_version=None, conflicts=(),
                software_name="Software"):
-    from distutils.version import LooseVersion
     package_name_l = package_name.lower()
     if package_name_l == 'pytango':
-        curr_version = LooseVersion(Release.version)
+        curr_version = Version(Release.version)
     elif package_name_l == 'tango':
-        curr_version = LooseVersion(TgLibVers)
+        curr_version = Version(TgLibVers)
     else:
         try:
             package = __import(package_name)
-            curr_version = LooseVersion(package.__version__)
+            curr_version = Version(package.__version__)
         except ImportError:
-            msg = "Could not find package {0} required by {1}".format(
-                package_name, software_name)
+            msg = f"Could not find package {package_name} required by {software_name}"
             raise Exception(msg)
-        except:
-            msg = "Error importing package {0} required by {1}".format(
-                package_name, software_name)
+        except Exception:
+            msg = f"Error importing package {package_name} required by {software_name}"
             raise Exception(msg)
 
     if min_version is not None:
-        min_version = LooseVersion(min_version)
+        min_version = Version(min_version)
         if min_version > curr_version:
-            msg = "{0} requires {1} {2} but {3} installed".format(
-                software_name, package_name, min_version, curr_version)
+            msg = f"{software_name} requires {package_name} {min_version} but {curr_version} installed"
             raise Exception(msg)
 
-    conflicts = map(LooseVersion, conflicts)
+    conflicts = map(Version, conflicts)
     if curr_version in conflicts:
-        msg = "{0} cannot run with {1} {2}".format(
-            software_name, package_name, curr_version)
+        msg = f"{software_name} cannot run with {package_name} {curr_version}"
         raise Exception(msg)
     return True
 
@@ -271,20 +261,20 @@ def requires_pytango(min_version=None, conflicts=(),
 
         from tango import requires_pytango
 
-        requires_pytango('7.1', conflicts=['8.1.1'], software='MyDS')
+        requires_pytango('7.1', conflicts=['8.1.1'], software_name='MyDS')
 
     :param min_version:
         minimum PyTango version [default: None, meaning no minimum
         required]. If a string is given, it must be in the valid
         version number format
-        (see: :class:`~distutils.version.LooseVersion`)
+        (see: :class:`~packaging.version.Version`)
     :type min_version:
-        None, str, :class:`~distutils.version.LooseVersion`
-    :param conflics:
+        None, str, :class:`~packaging.version.Version`
+    :param conflicts:
         a sequence of PyTango versions which conflict with the
         software using it
-    :type conflics:
-        seq<str|LooseVersion>
+    :type conflicts:
+        seq<str|Version>
     :param software_name:
         software name using tango. Used in the exception message
     :type software_name: str
@@ -299,26 +289,26 @@ def requires_pytango(min_version=None, conflicts=(),
 
 def requires_tango(min_version=None, conflicts=(), software_name="Software"):
     """
-    Determines if the required Tango version for the running
+    Determines if the required cppTango version for the running
     software is present. If not an exception is thrown.
     Example usage::
 
         from tango import requires_tango
 
-        requires_tango('7.1', conflicts=['8.1.1'], software='MyDS')
+        requires_tango('7.1', conflicts=['8.1.1'], software_name='MyDS')
 
     :param min_version:
         minimum Tango version [default: None, meaning no minimum
         required]. If a string is given, it must be in the valid
         version number format
-        (see: :class:`~distutils.version.LooseVersion`)
+        (see: :class:`~packaging.version.Version`)
     :type min_version:
-        None, str, :class:`~distutils.version.LooseVersion`
-    :param conflics:
+        None, str, :class:`~packaging.version.Version`
+    :param conflicts:
         a sequence of Tango versions which conflict with the
         software using it
-    :type conflics:
-        seq<str|LooseVersion>
+    :type conflicts:
+        seq<str|Version>
     :param software_name:
         software name using Tango. Used in the exception message
     :type software_name: str
@@ -338,7 +328,7 @@ def get_tango_device_classes():
         __device_classes = [_tango.DeviceImpl]
         i = 2
         while True:
-            dc = "Device_{0}Impl".format(i)
+            dc = f"Device_{i}Impl"
             try:
                 __device_classes.append(getattr(_tango, dc))
                 i = i + 1
@@ -358,7 +348,7 @@ except NameError:
 
 __int_klasses = int,
 __number_klasses = numbers.Number,
-__seq_klasses = collections_abc.Sequence, bytearray, StdStringVector
+__seq_klasses = collections.abc.Sequence, bytearray, StdStringVector
 
 __use_unicode = False
 try:
@@ -389,6 +379,39 @@ __number_klasses = tuple(__number_klasses)
 __seq_klasses = tuple(__seq_klasses)
 
 
+def set_complex_value(attr, value):
+    is_tuple = isinstance(value, tuple)
+    dtype, fmt = attr.get_data_type(), attr.get_data_format()
+    if dtype == CmdArgType.DevEncoded:
+        if is_tuple and len(value) == 4:
+            attr.set_value_date_quality(*value)
+        elif is_tuple and len(value) == 3 and is_non_str_seq(value[0]):
+            attr.set_value_date_quality(value[0][0],
+                                        value[0][1],
+                                        *value[1:])
+        else:
+            attr.set_value(*value)
+    else:
+        if is_tuple:
+            if len(value) == 3:
+                if fmt == AttrDataFormat.SCALAR:
+                    attr.set_value_date_quality(*value)
+                elif fmt == AttrDataFormat.SPECTRUM:
+                    if is_seq(value[0]):
+                        attr.set_value_date_quality(*value)
+                    else:
+                        attr.set_value(value)
+                else:
+                    if is_seq(value[0]) and is_seq(value[0][0]):
+                        attr.set_value_date_quality(*value)
+                    else:
+                        attr.set_value(value)
+            else:
+                attr.set_value(value)
+        else:
+            attr.set_value(value)
+
+
 def __get_tango_type(obj):
     if is_non_str_seq(obj):
         tg_type, tg_format = get_tango_type(obj[0])
@@ -411,8 +434,8 @@ def __get_tango_type_numpy_support(obj):
     try:
         ndim, dtype = obj.ndim, str(obj.dtype)
         if ndim > 2:
-            raise TypeError('cannot translate numpy array with {0} '
-                            'dimensions to tango type'.format(obj.ndim))
+            raise TypeError(f'cannot translate numpy array with {obj.ndim} '
+                            f'dimensions to tango type')
         return TO_TANGO_TYPE[dtype], AttrDataFormat(ndim)
     except AttributeError:
         return __get_tango_type(obj)
@@ -445,27 +468,24 @@ def get_enum_labels(enum_cls):
     :raises EnumTypeError: in case the given class is invalid
     """
     if not issubclass(enum_cls, enum.Enum):
-        raise EnumTypeError("Input class '%s' must be derived from enum.Enum"
-                            % enum_cls)
+        raise EnumTypeError(f"Input class '{enum_cls}' must be derived from enum.Enum")
 
     # Check there are no duplicate labels
     try:
         enum.unique(enum_cls)
     except ValueError as exc:
-        raise EnumTypeError("Input class '%s' must be unique - %s"
-                            % (enum_cls, exc))
+        raise EnumTypeError(f"Input class '{enum_cls}' must be unique - {exc}")
 
     # Check the values start at 0, and increment by 1, since that is
     # assumed by tango's DEV_ENUM implementation.
     values = [member.value for member in enum_cls]
     if not values:
-        raise EnumTypeError("Input class '%s' has no members!" % enum_cls)
+        raise EnumTypeError(f"Input class '{enum_cls}' has no members!")
     expected_value = 0
     for value in values:
         if value != expected_value:
-            raise EnumTypeError("Enum values for '%s' must start at 0 and "
-                                "increment by 1.  Values: %s"
-                                % (enum_cls, values))
+            raise EnumTypeError(f"Enum values for '{enum_cls}' must start at 0 and "
+                                f"increment by 1.  Values: {values}")
         expected_value += 1
 
     return [member.name for member in enum_cls]
@@ -521,6 +541,29 @@ def is_non_str_seq(obj):
     """
     return is_seq(obj) and not is_pure_str(obj)
 
+def is_devstate(obj):
+    return inspect.isclass(obj) and issubclass(obj, DevState)
+
+
+def is_devstate_seq(obj):
+    if is_non_str_seq(obj):
+        while is_non_str_seq(obj):
+            obj = obj[0]
+        return is_devstate(obj)
+    return False
+
+
+def is_enum(obj):
+    return inspect.isclass(obj) and issubclass(obj, enum.Enum)
+
+
+def is_enum_seq(obj):
+    if is_non_str_seq(obj):
+        while is_non_str_seq(obj) and len(obj):
+            obj = obj[0]
+        return is_enum(obj)
+    return False
+
 
 def is_integer(obj):
     """
@@ -876,8 +919,7 @@ def DbData_2_dict(db_data, d=None):
         d = {}
     if not isinstance(db_data, DbData):
         raise TypeError(
-            'db_data must be a tango.DbData. A %s found instead' %
-            type(db_data))
+            f'db_data must be a tango.DbData. A {type(db_data)} found instead')
     for db_datum in db_data:
         d[db_datum.name] = db_datum.value_string
     return d
@@ -996,7 +1038,7 @@ def scalar_to_array_type(tg_type):
     try:
         return _scalar_to_array_type[tg_type]
     except KeyError:
-        raise ValueError("Invalid tango scalar type: {0}".format(tg_type))
+        raise ValueError(f"Invalid tango scalar type: {tg_type}")
 
 
 def str_2_obj(obj_str, tg_type=None):
@@ -1061,7 +1103,7 @@ def obj_2_property(value):
         value = new_value
     elif is_non_str_seq(value):
         value = seq_2_DbData(value)
-    elif isinstance(value, collections_abc.Mapping):
+    elif isinstance(value, collections.abc.Mapping):
         new_value = DbData()
         for k, v in value.items():
             if isinstance(v, DbDatum):
@@ -1107,7 +1149,7 @@ def document_method(klass, method_name, d, add=True):
     if add:
         cpp_doc = meth.__doc__
         if cpp_doc:
-            func.__doc__ = "%s\n%s" % (d, cpp_doc)
+            func.__doc__ = f"{d}\n{cpp_doc}"
             return
     func.__doc__ = d
 
@@ -1123,27 +1165,23 @@ def document_static_method(klass, method_name, d, add=True):
     if add:
         cpp_doc = meth.__doc__
         if cpp_doc:
-            meth.__doc__ = "%s\n%s" % (d, cpp_doc)
+            meth.__doc__ = f"{d}\n{cpp_doc}"
             return
     meth.__doc__ = d
 
 
 def document_enum(klass, enum_name, desc, append=True):
-    # derived = type(base)('derived', (base,), {'__doc__': 'desc'})
 
     # Get the original enum type
-    base = getattr(klass, enum_name)
+    enum_class = getattr(klass, enum_name)
 
-    # Prepare the new docstring
-    if append and base.__doc__ is not None:
-        desc = base.__doc__ + "\n" + desc
-
-    # Create a new type, derived from the original. Only difference
-    # is the docstring.
-    derived = type(base)(enum_name, (base,), {'__doc__': desc})
-
-    # Replace the original enum type with the new one
-    setattr(klass, enum_name, derived)
+    # fix the docstring
+    # is __doc__ is not empty, expand with given desc
+    if append and enum_class.__doc__ is not None:
+        enum_class.__doc__ += "\n" + desc
+    # otherwise make a new one
+    else:
+        enum_class.__doc__ = desc
 
 
 class CaselessList(list):
@@ -1165,9 +1203,8 @@ class CaselessList(list):
         for entry in inlist:
             if not isinstance(entry, str):
                 raise TypeError(
-                    'Members of this object must be strings. '
-                    'You supplied \"%s\" which is \"%s\"' %
-                    (entry, type(entry)))
+                    f'Members of this object must be strings. '
+                    f'You supplied "{entry}" which is "{type(entry)}"')
             self.append(entry)
 
     def findentry(self, item):
@@ -1175,8 +1212,7 @@ class CaselessList(list):
         It returns None or the entry."""
         if not isinstance(item, str):
             raise TypeError(
-                'Members of this object must be strings. '
-                'You supplied \"%s\"' % type(item))
+                f'Members of this object must be strings. You supplied "{type(item)}"')
         for entry in self:
             if item.lower() == entry.lower():
                 return entry
@@ -1213,8 +1249,7 @@ class CaselessList(list):
         """Adds an item to the list and checks it's a string."""
         if not isinstance(item, str):
             raise TypeError(
-                'Members of this object must be strings. '
-                'You supplied \"%s\"' % type(item))
+                f'Members of this object must be strings. You supplied "{type(item)}"')
         list.append(self, item)
 
     def extend(self, item):
@@ -1222,13 +1257,12 @@ class CaselessList(list):
         a string."""
         if not isinstance(item, list):
             raise TypeError(
-                'You can only extend lists with lists. '
-                'You supplied \"%s\"' % type(item))
+                f'You can only extend lists with lists. You supplied "{type(item)}"')
         for entry in item:
             if not isinstance(entry, str):
                 raise TypeError(
-                    'Members of this object must be strings. '
-                    'You supplied \"%s\"' % type(entry))
+                    f'Members of this object must be strings. '
+                    f'You supplied "{type(entry)}"')
             list.append(self, entry)
 
     def count(self, item):
@@ -1255,8 +1289,7 @@ class CaselessList(list):
         maxindex = min(len(self), maxindex)
         if not isinstance(item, str):
             raise TypeError(
-                'Members of this object must be strings. '
-                'You supplied \"%s\"' % type(item))
+                f'Members of this object must be strings. You supplied "{type(item)}"')
         index = minindex
         while index < maxindex:
             index += 1
@@ -1269,8 +1302,7 @@ class CaselessList(list):
         Raises TypeError if x isn't a string."""
         if not isinstance(x, str):
             raise TypeError(
-                'Members of this object must be strings. '
-                'You supplied \"%s\"' % type(x))
+                f'Members of this object must be strings. You supplied "{type(x)}"')
         list.insert(self, i, x)
 
     def __setitem__(self, index, value):
@@ -1284,8 +1316,8 @@ class CaselessList(list):
         if isinstance(index, int):
             if not isinstance(value, str):
                 raise TypeError(
-                    'Members of this object must be strings. '
-                    'You supplied \"%s\"' % type(value))
+                    f'Members of this object must be strings. '
+                    f'You supplied "{type(value)}"')
             list.__setitem__(self, index, value)
         elif isinstance(index, slice):
             if not hasattr(value, '__len__'):
@@ -1294,8 +1326,8 @@ class CaselessList(list):
             for entry in value:
                 if not isinstance(entry, str):
                     raise TypeError(
-                        'Members of this object must be strings. '
-                        'You supplied \"%s\"' % type(entry))
+                        f'Members of this object must be strings. '
+                        f'You supplied "{type(entry)}"')
             list.__setitem__(self, index, value)
         else:
             raise TypeError('Indexes must be integers or slice objects.')
@@ -1305,8 +1337,8 @@ class CaselessList(list):
         for entry in sequence:
             if not isinstance(entry, str):
                 raise TypeError(
-                    'Members of this object must be strings. '
-                    'You supplied \"%s\"' % type(entry))
+                    f'Members of this object must be strings. '
+                    f'You supplied "{type(entry)}"')
         list.__setslice__(self, i, j, sequence)
 
     def __getslice__(self, i, j):
@@ -1482,7 +1514,7 @@ def _notifd2db_real_db(ior_string, host=None, out=sys.stdout):
               "to TANGO database", file=out)
 
 
-class EventCallback(object):
+class EventCallback:
     """
     Useful event callback for test purposes
 
@@ -1526,8 +1558,7 @@ class EventCallback(object):
         try:
             self._push_event(evt)
         except Exception as e:
-            print("Unexpected error in callback for %s: %s"
-                  % (str(evt), str(e)), file=self._fd)
+            print(f"Unexpected error in callback for {evt}: {e}", file=self._fd)
 
     def _push_event(self, evt):
         """Internal usage only"""
@@ -1536,28 +1567,28 @@ class EventCallback(object):
         now = datetime.datetime.now()
         try:
             date = self._get_date(evt)
-        except:
+        except Exception:
             date = now
         try:
             reception_date = evt.reception_date.todatetime()
-        except:
+        except Exception:
             reception_date = now
         try:
             evt_type = evt.event.upper()
-        except:
+        except Exception:
             evt_type = "<UNKNOWN>"
         try:
             dev_name = evt.device.dev_name().upper()
-        except:
+        except Exception:
             dev_name = "<UNKNOWN>"
         try:
             attr_name = evt.attr_name.split("/")[-1].upper()
-        except:
+        except Exception:
             attr_name = "<UNKNOWN>"
         try:
             value = self._get_value(evt)
         except Exception as e:
-            value = "Unexpected exception in getting event value: %s" % str(e)
+            value = f"Unexpected exception in getting event value: {e}"
         d = {"date": date, "reception_date": reception_date,
              "type": evt_type, "dev_name": dev_name, "name": attr_name,
              "value": value}
@@ -1582,14 +1613,13 @@ class EventCallback(object):
         """Internal usage only"""
         if evt.err:
             e = evt.errors[0]
-            return "[%s] %s" % (e.reason, e.desc)
+            return f"[{e.reason}] {e.desc}"
 
         if isinstance(evt, EventData):
-            return "[%s] %s" % (
-                evt.attr_value.quality, str(evt.attr_value.value))
+            return f"[{evt.attr_value.quality}] {evt.attr_value.value}"
         elif isinstance(evt, AttrConfEventData):
             cfg = evt.attr_conf
-            return "label='%s'; unit='%s'" % (cfg.label, cfg.unit)
+            return f"label='{cfg.label}'; unit='{cfg.unit}'"
         elif isinstance(evt, DataReadyEventData):
             return ""
         elif isinstance(evt, PipeEventData):
@@ -1611,7 +1641,7 @@ def get_home():
     path = ''
     try:
         path = os.path.expanduser("~")
-    except:
+    except Exception:
         pass
     if not os.path.isdir(path):
         for evar in ('HOME', 'USERPROFILE', 'TMP'):
@@ -1619,7 +1649,7 @@ def get_home():
                 path = os.environ[evar]
                 if os.path.isdir(path):
                     break
-            except:
+            except Exception:
                 pass
     if path:
         return path
@@ -1684,23 +1714,22 @@ def from_version_str_to_int(version_str):
 def info():
     # Compile and Runtime are set by `tango.pytango_init.init`
     from .constants import Compile, Runtime
-    msg = """\
-PyTango {0.version} {0.version_info}
+    msg = f"""\
+PyTango {Release.version_long} {Release.version_info}
 PyTango compiled with:
-    Python : {1.PY_VERSION}
-    Numpy  : {1.NUMPY_VERSION}
-    Tango  : {1.TANGO_VERSION}
-    Boost  : {1.BOOST_VERSION}
+    Python : {Compile.PY_VERSION}
+    Numpy  : {Compile.NUMPY_VERSION}
+    Tango  : {Compile.TANGO_VERSION}
+    Boost  : {Compile.BOOST_VERSION}
 
 PyTango runtime is:
-    Python : {2.PY_VERSION}
-    Numpy  : {2.NUMPY_VERSION}
-    Tango  : {2.TANGO_VERSION}
+    Python : {Runtime.PY_VERSION}
+    Numpy  : {Runtime.NUMPY_VERSION}
+    Tango  : {Runtime.TANGO_VERSION}
 
 PyTango running on:
-{2.UNAME}
+{Runtime.UNAME}
 """
-    msg = msg.format(Release, Compile, Runtime)
     return msg
 
 
@@ -1708,10 +1737,10 @@ def get_attrs(obj):
     """Helper for dir2 implementation."""
     if not hasattr(obj, '__dict__'):
         return []  # slots only
-    proxy_type = types.MappingProxyType if six.PY3 else types.DictProxyType
+    proxy_type = types.MappingProxyType
     if not isinstance(obj.__dict__, (dict, proxy_type)):
         print(type(obj.__dict__), obj)
-        raise TypeError("%s.__dict__ is not a dictionary" % obj.__name__)
+        raise TypeError(f"{obj.__name__}.__dict__ is not a dictionary")
     return obj.__dict__.keys()
 
 
@@ -1741,45 +1770,36 @@ def dir2(obj):
     return list(attrs)
 
 
-if hasattr(six, "ensure_binary"):
-    ensure_binary = six.ensure_binary
-else:
-    # For older versions of six (<1.12), fallback to local
-    # implementation
+def ensure_binary(s, encoding='utf-8', errors='strict'):
+    """Coerce **s** to the bytes type.
+    For Python 3:
+        - `str` -> encoded to `bytes`
+        - `bytes` -> `bytes`
 
-    def ensure_binary(s, encoding='utf-8', errors='strict'):
-        """Coerce **s** to six.binary_type.
-        For Python 2:
-          - `unicode` -> encoded to `str`
-          - `str` -> `str`
-        For Python 3:
-          - `str` -> encoded to `bytes`
-          - `bytes` -> `bytes`
-
-        Code taken from https://github.com/benjaminp/six/blob/1.12.0/six.py#L853
-        """
-        if isinstance(s, six.text_type):
-            return s.encode(encoding, errors)
-        elif isinstance(s, six.binary_type):
-            return s
-        else:
-            raise TypeError("not expecting type '%s'" % type(s))
+    Code taken from https://github.com/benjaminp/six/blob/1.12.0/six.py#L853
+    """
+    if isinstance(s, str):
+        return s.encode(encoding, errors)
+    elif isinstance(s, bytes):
+        return s
+    else:
+        raise TypeError(f"not expecting type '{type(s)}'")
 
 
 class PyTangoHelpFormatter(HelpFormatter):
 
     def _format_usage(self, usage, actions, groups, prefix):
-        usage = super(PyTangoHelpFormatter, self)._format_usage(usage, actions, groups, prefix)
+        usage = super()._format_usage(usage, actions, groups, prefix)
         try:
             db = Database()
             servers_list = db.get_instance_name_list(self._prog)
             if servers_list.size():
-                usage += 'Instance names defined in database for server {}:\n'.format(self._prog)
+                usage += f'Instance names defined in database for server {self._prog}:\n'
                 for server in servers_list:
                     usage += '\t' + str(server) + '\n'
             else:
-                usage += 'Warning! No defined instance in database for server {} found!\n'.format(self._prog)
+                usage += f'Warning! No defined instance in database for server {self._prog} found!\n'
         except DevFailed:
             pass
 
-        return usage
\ No newline at end of file
+        return usage
