@@ -1,14 +1,16 @@
 """Load tango-specific pytest fixtures."""
 
-from tango.test_utils import state, typed_values, server_green_mode
-
+from tango.test_utils import state, command_typed_values, attribute_typed_values
+from tango.test_utils import server_green_mode, attr_data_format
+from tango.test_utils import extract_as, base_type
 import pytest
 
 import sys
 import os
 import json
 
-__all__ = ("state", "typed_values", "server_green_mode")
+__all__ = ("state", "command_typed_values", "attribute_typed_values",
+           "server_green_mode", "attr_data_format", "extract_as", "base_type")
 
 
 @pytest.hookimpl()
@@ -23,7 +25,7 @@ def pytest_sessionfinish(session):
                 f.write(
                     "pytest -c pytest_empty_config.txt -v "
                 )  # this empty file is created by appveyor
-                f.write('"{}"\n'.format(item.nodeid))
+                f.write(f'"{item.nodeid}"\n')
                 # Abort if pytest could not execute properly
                 # From: https://docs.pytest.org/en/7.1.x/reference/exit-codes.html
                 #   Exit code 0: All tests were collected and passed successfully
@@ -47,7 +49,7 @@ def pytest_runtest_makereport():
             summary = f.read()
             try:
                 summary = json.loads(summary)
-            except:
+            except Exception:
                 summary = []
             finally:
                 outcome = str(result.outcome).capitalize()
