@@ -1,5 +1,3 @@
-
-
 # Imports
 from concurrent.futures import Future
 
@@ -11,8 +9,8 @@ from tango.server import Device, command
 from tango.test_utils import DeviceTestContext
 
 
-def test_async_command_polled(typed_values):
-    dtype, values, expected = typed_values
+def test_async_command_polled(command_typed_values):
+    dtype, values, expected = command_typed_values
 
     if dtype == (bool,):
         pytest.xfail('Not supported for some reasons')
@@ -30,15 +28,11 @@ def test_async_command_polled(typed_values):
             assert_array_equal(result, expected(value))
 
 
-def test_async_command_with_polled_callback(typed_values):
-    dtype, values, expected = typed_values
-
-    if dtype == (bool,):
-        pytest.xfail('Not supported for some reasons')
+def test_async_command_with_polled_callback():
 
     class TestDevice(Device):
 
-        @command(dtype_in=dtype, dtype_out=dtype)
+        @command(dtype_in=int, dtype_out=int)
         def identity(self, arg):
             return arg
 
@@ -46,23 +40,18 @@ def test_async_command_with_polled_callback(typed_values):
     api_util.set_asynch_cb_sub_model(tango.cb_sub_model.PULL_CALLBACK)
 
     with DeviceTestContext(TestDevice) as proxy:
-        for value in values:
-            future = Future()
-            proxy.command_inout_asynch('identity', value, future.set_result)
-            api_util.get_asynch_replies(500)
-            result = future.result()
-            assert_array_equal(result.argout, expected(value))
+        future = Future()
+        proxy.command_inout_asynch('identity', 123, future.set_result)
+        api_util.get_asynch_replies(500)
+        result = future.result()
+        assert_array_equal(result.argout, 123)
 
 
-def test_async_command_with_pushed_callback(typed_values):
-    dtype, values, expected = typed_values
-
-    if dtype == (bool,):
-        pytest.xfail('Not supported for some reasons')
+def test_async_command_with_pushed_callback():
 
     class TestDevice(Device):
 
-        @command(dtype_in=dtype, dtype_out=dtype)
+        @command(dtype_in=int, dtype_out=int)
         def identity(self, arg):
             return arg
 
@@ -70,8 +59,7 @@ def test_async_command_with_pushed_callback(typed_values):
     api_util.set_asynch_cb_sub_model(tango.cb_sub_model.PUSH_CALLBACK)
 
     with DeviceTestContext(TestDevice) as proxy:
-        for value in values:
-            future = Future()
-            proxy.command_inout_asynch('identity', value, future.set_result)
-            result = future.result(timeout=0.5)
-            assert_array_equal(result.argout, expected(value))
+        future = Future()
+        proxy.command_inout_asynch('identity', 123, future.set_result)
+        result = future.result(timeout=0.5)
+        assert_array_equal(result.argout, 123)
